import * as i0 from '@angular/core';
import { EventEmitter, Component, ChangeDetectionStrategy, ViewEncapsulation, ViewChild, Output, Input, Directive, InjectionToken, Pipe, isDevMode, Attribute, Optional, Inject, Self, ViewChildren, ContentChild, NgModule } from '@angular/core';
import * as i2$1 from '@angular/forms';
import { Validators, FormsModule } from '@angular/forms';
import { SelectionModel } from '@angular/cdk/collections';
import * as i4 from '@angular/cdk/scrolling';
import { CdkVirtualScrollViewport, ScrollingModule } from '@angular/cdk/scrolling';
import { coerceBooleanProperty } from '@angular/cdk/coercion';
import * as i13 from '@angular/material/form-field';
import { MAT_FORM_FIELD, MatFormFieldControl } from '@angular/material/form-field';
import * as i1$2 from '@angular/material/core';
import { mixinDisableRipple, mixinTabIndex, mixinDisabled, mixinErrorState, MAT_OPTION_PARENT_COMPONENT, MatOption, MatOptionModule } from '@angular/material/core';
import { Subject, BehaviorSubject, tap, fromEvent, of, ReplaySubject, merge, combineLatest, pairwise } from 'rxjs';
import * as i2 from '@angular/cdk/overlay';
import { CdkConnectedOverlay, CdkOverlayOrigin } from '@angular/cdk/overlay';
import { takeUntil, startWith, map, debounceTime, filter, take, distinctUntilChanged, combineLatestWith, withLatestFrom, switchMap } from 'rxjs/operators';
import { trigger, transition, query, animateChild, state, style, animate } from '@angular/animations';
import * as i1 from '@angular/cdk/bidi';
import * as i1$1 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i2$2 from '@angular/material/progress-bar';
import { MatProgressBarModule } from '@angular/material/progress-bar';
import * as i2$3 from '@angular/material/chips';
import { MatChipsModule } from '@angular/material/chips';

/**
 * The following are all the animations for the mat-select component, with each
 * const containing the metadata for one animation.
 *
 * The values below match the implementation of the AngularJS Material mat-select animation.
 * @docs-private
 */
const matSelectAnimations = {
    /**
     * This animation ensures the select's overlay panel animation (transformPanel) is called when
     * closing the select.
     * This is needed due to https://github.com/angular/angular/issues/23302
     */
    transformPanelWrap: trigger('transformPanelWrap', [
        transition('* => void', query('@transformPanel', [animateChild()], { optional: true })),
    ]),
    /** This animation transforms the select's overlay panel on and off the page. */
    transformPanel: trigger('transformPanel', [
        state('void', style({
            opacity: 0,
            transform: 'scale(1, 0.8)',
        })),
        transition('void => showing', animate('120ms cubic-bezier(0, 0, 0.2, 1)', style({
            opacity: 1,
            transform: 'scale(1, 1)',
        }))),
        transition('* => void', animate('100ms linear', style({ opacity: 0 }))),
    ]),
};

/**
 * to check being undefined or null
 * @param value
 */
function isNullOrUndefined(value) {
    return value === undefined || value === null;
}

/**
 * a panel which will be connected to the trigger element
 */
class NgxMatSelectPanelComponent {
    constructor(dir, changeDetectorRef, viewportRuler) {
        this.dir = dir;
        this.changeDetectorRef = changeDetectorRef;
        this.viewportRuler = viewportRuler;
        /**
         * it raises an event before the panel gets close
         * */
        this.beforeClose = new EventEmitter();
        /**
         * it raises an event after the panel gets close
         * */
        this.afterClose = new EventEmitter();
        /**
         * it raises an event after the panel gets open
         * */
        this.afterOpen = new EventEmitter();
        /**
         * it raises an event before the panel gets open
         * */
        this.beforeOpen = new EventEmitter();
        /**
         * if it's true it shows a back-drop behind the panel
         */
        this.hasBackdrop = true;
        /**
         * if it's true the panel does not open
         */
        this.disabled = false;
        this._overlayClass = '';
        /** Classes to be passed to the select panel. Supports the same syntax as `ngClass`. */
        this.panelClass = [];
        this._width = 'auto';
        /**
         * the height of the panel
         */
        this.height = 350;
        this._viewType = 'Default';
        this.overlayClassViewType = 'ngx-mat-select-default-view-type';
        this._panelWidth = 'auto';
        this._positions = [
            {
                originX: 'start',
                originY: 'bottom',
                overlayX: 'start',
                overlayY: 'top',
            },
            {
                originX: 'end',
                originY: 'bottom',
                overlayX: 'end',
                overlayY: 'top',
            },
            {
                originX: 'start',
                originY: 'top',
                overlayX: 'start',
                overlayY: 'bottom',
                panelClass: 'ngx-mat-select-panel-above',
            },
            {
                originX: 'end',
                originY: 'top',
                overlayX: 'end',
                overlayY: 'bottom',
                panelClass: 'ngx-mat-select-panel-above',
            },
        ];
        /**
         * an observable to manage destroying the other observables
         * @private
         */
        this.destroy$ = new Subject();
        /**
         * a subject to control the opening of the panel with it
         * @private
         */
        this.isOpen$$ = new BehaviorSubject(false);
        this.isOpen$ = this.isOpen$$.asObservable();
    }
    /** Class or list of classes to be applied to the menu's overlay panel. */
    get overlayClass() {
        return this._overlayClass;
    }
    set overlayClass(value) {
        this._overlayClass = Array.isArray(value)
            ? (value.join(' '))
            : value;
    }
    /**
     * the origin element that we want to connect it with the panel
     */
    get connectedOverlayOrigin() {
        return this._connectedOverlayOrigin;
    }
    set connectedOverlayOrigin(value) {
        this._connectedOverlayOrigin = value;
        this.updateOverlayWidth();
    }
    /**
     * the width of the panel
     */
    get width() {
        return this._width;
    }
    set width(value) {
        this._width = value;
        this.updateOverlayWidth();
    }
    get viewType() {
        return this._viewType;
    }
    /**
     * how to show the panel, it can be 'BottomSheet', 'FullScreen' and 'Default'
     * @param value
     */
    set viewType(value) {
        this._viewType = value;
        let css = '';
        switch (value) {
            case 'BottomSheet':
                css = 'bottom-sheet';
                break;
            case 'FullScreen':
                css = 'full-screen';
                break;
            default:
            case 'Default':
                css = 'default';
                break;
        }
        this.overlayClassViewType = `ngx-mat-select-panel-${css}-view-type`;
    }
    ngOnInit() {
        this.viewportRuler
            .change()
            .pipe(takeUntil(this.destroy$))
            .subscribe(() => {
            if (this.isOpen) {
                this.updateOverlayWidth();
                this.changeDetectorRef.detectChanges();
            }
        });
    }
    get isOpen() {
        return this.isOpen$$.getValue();
    }
    ngAfterViewInit() {
        this.syncDirection();
    }
    /**
     * whenever we want to update the position of the panel due to the position changes in the trigger origin element
     * we should call this method
     */
    updatePosition() {
        this.overlay.overlayRef.updatePosition();
    }
    /**
     * to close the panel
     * @param event
     */
    onOutsideClick(event) {
        var _a;
        if (event.target && ((_a = this.connectedOverlayOrigin) === null || _a === void 0 ? void 0 : _a.nativeElement.contains(event.target))) {
            event.stopPropagation();
        }
        this.close();
    }
    /**
     * to open the panel
     */
    open() {
        this.beforeOpen.emit();
        if (!this.disabled) {
            this.isOpen$$.next(true);
        }
    }
    /**
     * to close the panel
     */
    close() {
        this.beforeClose.emit();
        this.isOpen$$.next(false);
    }
    onOverlayKeyDown(event) {
        if (event.code === 'Escape') {
            this.close();
        }
    }
    /** sets how wide the overlay panel should be. */
    updateOverlayWidth() {
        var _a;
        if (this.width === 'auto') {
            this._panelWidth = (_a = this.connectedOverlayOrigin) === null || _a === void 0 ? void 0 : _a.nativeElement.getBoundingClientRect().width;
        }
        else {
            this._panelWidth = isNullOrUndefined(this.width) ? '' : this.width;
        }
        this.changeDetectorRef.markForCheck();
    }
    ngOnDestroy() {
        this.destroy$.next(void 0);
        this.destroy$.complete();
        this.isOpen$$.complete();
    }
    /**
     * to sync the direction of the overlay with the body direction
     * @private
     */
    syncDirection() {
        this.dir.change
            .pipe(startWith(this.dir.value), tap(dir => {
            var _a;
            (_a = this.overlay.overlayRef) === null || _a === void 0 ? void 0 : _a.setDirection(dir);
            this.changeDetectorRef.detectChanges();
        }), takeUntil(this.destroy$))
            .subscribe();
    }
}
NgxMatSelectPanelComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.9", ngImport: i0, type: NgxMatSelectPanelComponent, deps: [{ token: i1.Directionality }, { token: i0.ChangeDetectorRef }, { token: i2.ViewportRuler }], target: i0.ɵɵFactoryTarget.Component });
NgxMatSelectPanelComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.9", type: NgxMatSelectPanelComponent, selector: "ngx-mat-select-panel", inputs: { hasBackdrop: "hasBackdrop", disabled: "disabled", theme: "theme", overlayClass: "overlayClass", panelClass: "panelClass", connectedOverlayOrigin: "connectedOverlayOrigin", width: "width", height: "height", viewType: "viewType" }, outputs: { beforeClose: "beforeClose", afterClose: "afterClose", afterOpen: "afterOpen", beforeOpen: "beforeOpen" }, viewQueries: [{ propertyName: "overlay", first: true, predicate: CdkConnectedOverlay, descendants: true }], ngImport: i0, template: "<ng-template\r\n  [cdkConnectedOverlayWidth]=\"_panelWidth\"\r\n  (overlayOutsideClick)=\"onOutsideClick($event)\"\r\n  cdkConnectedOverlay\r\n  [cdkConnectedOverlayOrigin]=\"connectedOverlayOrigin\"\r\n  [cdkConnectedOverlayOpen]=\"(isOpen$ | async) === true\"\r\n  [cdkConnectedOverlayLockPosition]=\"true\"\r\n  (attach)=\"afterOpen.emit()\"\r\n  [cdkConnectedOverlayPanelClass]=\"[overlayClassViewType, _overlayClass]\"\r\n  (overlayKeydown)=\"onOverlayKeyDown($event)\"\r\n  [cdkConnectedOverlayHasBackdrop]=\"hasBackdrop\"\r\n  [cdkConnectedOverlayPositions]=\"_positions\"\r\n  cdkConnectedOverlayBackdropClass=\"cdk-overlay-transparent-backdrop\"\r\n  (detach)=\"afterClose.emit()\">\r\n  <div\r\n    class=\"ngx-mat-select-panel mdc-menu-surface mdc-menu-surface--open {{ theme }}\"\r\n    [ngClass]=\"panelClass\"\r\n    [style.height.px]=\"viewType === 'Default'? height: ''\"\r\n    role=\"listbox\"\r\n    [@transformPanel]=\"(isOpen$ | async) ? 'showing' : ''\"\r\n  >\r\n    <ng-content></ng-content>\r\n  </div>\r\n</ng-template>\r\n", dependencies: [{ kind: "directive", type: i1$1.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i2.CdkConnectedOverlay, selector: "[cdk-connected-overlay], [connected-overlay], [cdkConnectedOverlay]", inputs: ["cdkConnectedOverlayOrigin", "cdkConnectedOverlayPositions", "cdkConnectedOverlayPositionStrategy", "cdkConnectedOverlayOffsetX", "cdkConnectedOverlayOffsetY", "cdkConnectedOverlayWidth", "cdkConnectedOverlayHeight", "cdkConnectedOverlayMinWidth", "cdkConnectedOverlayMinHeight", "cdkConnectedOverlayBackdropClass", "cdkConnectedOverlayPanelClass", "cdkConnectedOverlayViewportMargin", "cdkConnectedOverlayScrollStrategy", "cdkConnectedOverlayOpen", "cdkConnectedOverlayDisableClose", "cdkConnectedOverlayTransformOriginOn", "cdkConnectedOverlayHasBackdrop", "cdkConnectedOverlayLockPosition", "cdkConnectedOverlayFlexibleDimensions", "cdkConnectedOverlayGrowAfterOpen", "cdkConnectedOverlayPush"], outputs: ["backdropClick", "positionChange", "attach", "detach", "overlayKeydown", "overlayOutsideClick"], exportAs: ["cdkConnectedOverlay"] }, { kind: "pipe", type: i1$1.AsyncPipe, name: "async" }], animations: [matSelectAnimations.transformPanel], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.9", ngImport: i0, type: NgxMatSelectPanelComponent, decorators: [{
            type: Component,
            args: [{ selector: 'ngx-mat-select-panel', changeDetection: ChangeDetectionStrategy.OnPush, animations: [matSelectAnimations.transformPanel], encapsulation: ViewEncapsulation.None, template: "<ng-template\r\n  [cdkConnectedOverlayWidth]=\"_panelWidth\"\r\n  (overlayOutsideClick)=\"onOutsideClick($event)\"\r\n  cdkConnectedOverlay\r\n  [cdkConnectedOverlayOrigin]=\"connectedOverlayOrigin\"\r\n  [cdkConnectedOverlayOpen]=\"(isOpen$ | async) === true\"\r\n  [cdkConnectedOverlayLockPosition]=\"true\"\r\n  (attach)=\"afterOpen.emit()\"\r\n  [cdkConnectedOverlayPanelClass]=\"[overlayClassViewType, _overlayClass]\"\r\n  (overlayKeydown)=\"onOverlayKeyDown($event)\"\r\n  [cdkConnectedOverlayHasBackdrop]=\"hasBackdrop\"\r\n  [cdkConnectedOverlayPositions]=\"_positions\"\r\n  cdkConnectedOverlayBackdropClass=\"cdk-overlay-transparent-backdrop\"\r\n  (detach)=\"afterClose.emit()\">\r\n  <div\r\n    class=\"ngx-mat-select-panel mdc-menu-surface mdc-menu-surface--open {{ theme }}\"\r\n    [ngClass]=\"panelClass\"\r\n    [style.height.px]=\"viewType === 'Default'? height: ''\"\r\n    role=\"listbox\"\r\n    [@transformPanel]=\"(isOpen$ | async) ? 'showing' : ''\"\r\n  >\r\n    <ng-content></ng-content>\r\n  </div>\r\n</ng-template>\r\n" }]
        }], ctorParameters: function () { return [{ type: i1.Directionality }, { type: i0.ChangeDetectorRef }, { type: i2.ViewportRuler }]; }, propDecorators: { overlay: [{
                type: ViewChild,
                args: [CdkConnectedOverlay]
            }], beforeClose: [{
                type: Output
            }], afterClose: [{
                type: Output
            }], afterOpen: [{
                type: Output
            }], beforeOpen: [{
                type: Output
            }], hasBackdrop: [{
                type: Input
            }], disabled: [{
                type: Input
            }], theme: [{
                type: Input
            }], overlayClass: [{
                type: Input
            }], panelClass: [{
                type: Input
            }], connectedOverlayOrigin: [{
                type: Input
            }], width: [{
                type: Input
            }], height: [{
                type: Input
            }], viewType: [{
                type: Input
            }] } });

class NgxMatSelectIconComponent {
    constructor() {
        /**
         * the width of the icon in number
         */
        this.width = 24;
        /**
         * the height of the icon in number
         */
        this.height = 24;
    }
}
NgxMatSelectIconComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.9", ngImport: i0, type: NgxMatSelectIconComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
NgxMatSelectIconComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.9", type: NgxMatSelectIconComponent, selector: "ngx-mat-select-icon", inputs: { icon: "icon", width: "width", height: "height" }, ngImport: i0, template: "<ng-container [ngSwitch]=\"icon\">\r\n  <ng-container *ngSwitchCase=\"'Times'\">\r\n    <svg\r\n      xmlns=\"http://www.w3.org/2000/svg\"\r\n      x=\"0px\"\r\n      y=\"0px\"\r\n      [attr.width]=\"width\"\r\n      [attr.height]=\"height\"\r\n      viewBox=\"0 0 24 24\">\r\n      <path\r\n        d=\"M 4.9902344 3.9902344 A 1.0001 1.0001 0 0 0 4.2929688 5.7070312 L 10.585938 12 L 4.2929688 18.292969 A 1.0001 1.0001 0 1 0 5.7070312 19.707031 L 12 13.414062 L 18.292969 19.707031 A 1.0001 1.0001 0 1 0 19.707031 18.292969 L 13.414062 12 L 19.707031 5.7070312 A 1.0001 1.0001 0 0 0 18.980469 3.9902344 A 1.0001 1.0001 0 0 0 18.292969 4.2929688 L 12 10.585938 L 5.7070312 4.2929688 A 1.0001 1.0001 0 0 0 4.9902344 3.9902344 z\"></path>\r\n    </svg>\r\n  </ng-container>\r\n\r\n  <ng-container *ngSwitchCase=\"'ArrowRight'\">\r\n    <svg xmlns=\"http://www.w3.org/2000/svg\" [attr.width]=\"width\" [attr.height]=\"height\" viewBox=\"0 0 24 24\" fill=\"none\">\r\n      <g id=\"Arrow / Arrow_Right_LG\">\r\n        <path\r\n          id=\"Vector\"\r\n          d=\"M21 12L16 7M21 12L16 17M21 12H3\"\r\n          stroke-width=\"2\"\r\n          stroke-linecap=\"round\"\r\n          stroke-linejoin=\"round\" />\r\n      </g>\r\n    </svg>\r\n  </ng-container>\r\n\r\n  <ng-container *ngSwitchCase=\"'ArrowDown'\">\r\n    <svg viewBox=\"0 0 24 24\" [attr.width]=\"width\" [attr.height]=\"height\" focusable=\"false\" aria-hidden=\"true\">\r\n      <path d=\"M7 10l5 5 5-5z\" />\r\n    </svg>\r\n  </ng-container>\r\n\r\n  <ng-container *ngSwitchCase=\"'Remove'\">\r\n    <svg\r\n      xmlns=\"http://www.w3.org/2000/svg\"\r\n      x=\"0px\"\r\n      y=\"0px\"\r\n      [attr.width]=\"width\"\r\n      [attr.height]=\"height\"\r\n      viewBox=\"0 0 50 50\">\r\n      <path\r\n        d=\"M 25 2 C 12.309534 2 2 12.309534 2 25 C 2 37.690466 12.309534 48 25 48 C 37.690466 48 48 37.690466 48 25 C 48 12.309534 37.690466 2 25 2 z M 25 4 C 36.609534 4 46 13.390466 46 25 C 46 36.609534 36.609534 46 25 46 C 13.390466 46 4 36.609534 4 25 C 4 13.390466 13.390466 4 25 4 z M 32.990234 15.986328 A 1.0001 1.0001 0 0 0 32.292969 16.292969 L 25 23.585938 L 17.707031 16.292969 A 1.0001 1.0001 0 0 0 16.990234 15.990234 A 1.0001 1.0001 0 0 0 16.292969 17.707031 L 23.585938 25 L 16.292969 32.292969 A 1.0001 1.0001 0 1 0 17.707031 33.707031 L 25 26.414062 L 32.292969 33.707031 A 1.0001 1.0001 0 1 0 33.707031 32.292969 L 26.414062 25 L 33.707031 17.707031 A 1.0001 1.0001 0 0 0 32.990234 15.986328 z\"></path>\r\n    </svg>\r\n  </ng-container>\r\n\r\n  <ng-container *ngSwitchCase=\"'Search'\">\r\n    <svg\r\n      xmlns=\"http://www.w3.org/2000/svg\"\r\n      x=\"0px\"\r\n      y=\"0px\"\r\n      [attr.width]=\"width\"\r\n      [attr.height]=\"height\"\r\n      viewBox=\"0 0 50 50\">\r\n      <path\r\n        d=\"M 21 3 C 11.621094 3 4 10.621094 4 20 C 4 29.378906 11.621094 37 21 37 C 24.710938 37 28.140625 35.804688 30.9375 33.78125 L 44.09375 46.90625 L 46.90625 44.09375 L 33.90625 31.0625 C 36.460938 28.085938 38 24.222656 38 20 C 38 10.621094 30.378906 3 21 3 Z M 21 5 C 29.296875 5 36 11.703125 36 20 C 36 28.296875 29.296875 35 21 35 C 12.703125 35 6 28.296875 6 20 C 6 11.703125 12.703125 5 21 5 Z\"></path>\r\n    </svg>\r\n  </ng-container>\r\n</ng-container>\r\n", dependencies: [{ kind: "directive", type: i1$1.NgSwitch, selector: "[ngSwitch]", inputs: ["ngSwitch"] }, { kind: "directive", type: i1$1.NgSwitchCase, selector: "[ngSwitchCase]", inputs: ["ngSwitchCase"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.9", ngImport: i0, type: NgxMatSelectIconComponent, decorators: [{
            type: Component,
            args: [{ selector: 'ngx-mat-select-icon', changeDetection: ChangeDetectionStrategy.OnPush, template: "<ng-container [ngSwitch]=\"icon\">\r\n  <ng-container *ngSwitchCase=\"'Times'\">\r\n    <svg\r\n      xmlns=\"http://www.w3.org/2000/svg\"\r\n      x=\"0px\"\r\n      y=\"0px\"\r\n      [attr.width]=\"width\"\r\n      [attr.height]=\"height\"\r\n      viewBox=\"0 0 24 24\">\r\n      <path\r\n        d=\"M 4.9902344 3.9902344 A 1.0001 1.0001 0 0 0 4.2929688 5.7070312 L 10.585938 12 L 4.2929688 18.292969 A 1.0001 1.0001 0 1 0 5.7070312 19.707031 L 12 13.414062 L 18.292969 19.707031 A 1.0001 1.0001 0 1 0 19.707031 18.292969 L 13.414062 12 L 19.707031 5.7070312 A 1.0001 1.0001 0 0 0 18.980469 3.9902344 A 1.0001 1.0001 0 0 0 18.292969 4.2929688 L 12 10.585938 L 5.7070312 4.2929688 A 1.0001 1.0001 0 0 0 4.9902344 3.9902344 z\"></path>\r\n    </svg>\r\n  </ng-container>\r\n\r\n  <ng-container *ngSwitchCase=\"'ArrowRight'\">\r\n    <svg xmlns=\"http://www.w3.org/2000/svg\" [attr.width]=\"width\" [attr.height]=\"height\" viewBox=\"0 0 24 24\" fill=\"none\">\r\n      <g id=\"Arrow / Arrow_Right_LG\">\r\n        <path\r\n          id=\"Vector\"\r\n          d=\"M21 12L16 7M21 12L16 17M21 12H3\"\r\n          stroke-width=\"2\"\r\n          stroke-linecap=\"round\"\r\n          stroke-linejoin=\"round\" />\r\n      </g>\r\n    </svg>\r\n  </ng-container>\r\n\r\n  <ng-container *ngSwitchCase=\"'ArrowDown'\">\r\n    <svg viewBox=\"0 0 24 24\" [attr.width]=\"width\" [attr.height]=\"height\" focusable=\"false\" aria-hidden=\"true\">\r\n      <path d=\"M7 10l5 5 5-5z\" />\r\n    </svg>\r\n  </ng-container>\r\n\r\n  <ng-container *ngSwitchCase=\"'Remove'\">\r\n    <svg\r\n      xmlns=\"http://www.w3.org/2000/svg\"\r\n      x=\"0px\"\r\n      y=\"0px\"\r\n      [attr.width]=\"width\"\r\n      [attr.height]=\"height\"\r\n      viewBox=\"0 0 50 50\">\r\n      <path\r\n        d=\"M 25 2 C 12.309534 2 2 12.309534 2 25 C 2 37.690466 12.309534 48 25 48 C 37.690466 48 48 37.690466 48 25 C 48 12.309534 37.690466 2 25 2 z M 25 4 C 36.609534 4 46 13.390466 46 25 C 46 36.609534 36.609534 46 25 46 C 13.390466 46 4 36.609534 4 25 C 4 13.390466 13.390466 4 25 4 z M 32.990234 15.986328 A 1.0001 1.0001 0 0 0 32.292969 16.292969 L 25 23.585938 L 17.707031 16.292969 A 1.0001 1.0001 0 0 0 16.990234 15.990234 A 1.0001 1.0001 0 0 0 16.292969 17.707031 L 23.585938 25 L 16.292969 32.292969 A 1.0001 1.0001 0 1 0 17.707031 33.707031 L 25 26.414062 L 32.292969 33.707031 A 1.0001 1.0001 0 1 0 33.707031 32.292969 L 26.414062 25 L 33.707031 17.707031 A 1.0001 1.0001 0 0 0 32.990234 15.986328 z\"></path>\r\n    </svg>\r\n  </ng-container>\r\n\r\n  <ng-container *ngSwitchCase=\"'Search'\">\r\n    <svg\r\n      xmlns=\"http://www.w3.org/2000/svg\"\r\n      x=\"0px\"\r\n      y=\"0px\"\r\n      [attr.width]=\"width\"\r\n      [attr.height]=\"height\"\r\n      viewBox=\"0 0 50 50\">\r\n      <path\r\n        d=\"M 21 3 C 11.621094 3 4 10.621094 4 20 C 4 29.378906 11.621094 37 21 37 C 24.710938 37 28.140625 35.804688 30.9375 33.78125 L 44.09375 46.90625 L 46.90625 44.09375 L 33.90625 31.0625 C 36.460938 28.085938 38 24.222656 38 20 C 38 10.621094 30.378906 3 21 3 Z M 21 5 C 29.296875 5 36 11.703125 36 20 C 36 28.296875 29.296875 35 21 35 C 12.703125 35 6 28.296875 6 20 C 6 11.703125 12.703125 5 21 5 Z\"></path>\r\n    </svg>\r\n  </ng-container>\r\n</ng-container>\r\n" }]
        }], propDecorators: { icon: [{
                type: Input
            }], width: [{
                type: Input
            }], height: [{
                type: Input
            }] } });

/**
 * a search box that clint can search through all the options
 */
class NgxMatSelectSearchBoxComponent {
    constructor() {
        /**
         * it raises an event whenever the client write down a word on the input element.
         * the delay go with this property and the delay will cause a delay on the raising the event
         */
        this.search = new EventEmitter();
        /**
         * emits an event when the client press a keyboard
         */
        this.handleKeydown = new EventEmitter();
        /**
         * to make a debounce-time delay whenever the client write a word down, in millisecond
         */
        this.debounceTime = 200;
        /**
         * the placeholder on the input search-box
         */
        this.placeholder = '';
        /**
         * the value of the input which is bound to the input with two ways binding
         */
        this.value = '';
        /**
         * whether search-input is focused
         */
        this.focused = true;
        /**
         * an observable to manage destroying the other observables
         * @private
         */
        this.destroy$ = new Subject();
    }
    ngAfterViewInit() {
        this.initializeSearchBox();
    }
    /**
     * to handle focusing in the search-box
     */
    focus() {
        if (!this.focused) {
            this.focused = true;
        }
        this.searchBox.nativeElement.focus();
    }
    /**
     * to handle focusing in the search-box
     */
    blur() {
        if (this.focused) {
            this.focused = false;
        }
        this.searchBox.nativeElement.blur();
    }
    /**
     * to clear the input value
     */
    clear() {
        this.value = '';
        this.search.emit('');
    }
    /**
     * when blurring from the search-box input
     */
    _onBlur() {
        this.focused = false;
    }
    /**
     * when focusing on the search-box input
     */
    _onFocus() {
        this.focused = true;
    }
    ngOnDestroy() {
        this.destroy$.next(void 0);
        this.destroy$.complete();
    }
    /**
     * to listen to the search-box input event whenever a word is written down
     * @private
     */
    initializeSearchBox() {
        fromEvent(this.searchBox.nativeElement, 'input')
            .pipe(map((event) => event.target.value), debounceTime(this.debounceTime), startWith(''), tap(searchTerm => {
            this.search.emit(searchTerm);
        }), takeUntil(this.destroy$))
            .subscribe();
    }
}
NgxMatSelectSearchBoxComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.9", ngImport: i0, type: NgxMatSelectSearchBoxComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
NgxMatSelectSearchBoxComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.9", type: NgxMatSelectSearchBoxComponent, selector: "ngx-mat-select-search-box", inputs: { debounceTime: "debounceTime", placeholder: "placeholder" }, outputs: { search: "search", handleKeydown: "handleKeydown" }, host: { properties: { "class.ngx-mat-select-search-box--focused": "focused" }, classAttribute: "ngx-mat-select-search-box" }, viewQueries: [{ propertyName: "searchBox", first: true, predicate: ["searchBox"], descendants: true }], ngImport: i0, template: "<div class=\"ngx-mat-select-search-box-icon\">\r\n  <div *ngIf=\"!value\">\r\n    <ngx-mat-select-icon icon=\"Search\"> </ngx-mat-select-icon>\r\n  </div>\r\n\r\n  <div (click)=\"clear()\" *ngIf=\"!!value\">\r\n    <ngx-mat-select-icon icon=\"Times\"> </ngx-mat-select-icon>\r\n  </div>\r\n</div>\r\n\r\n<input\r\n  (blur)=\"_onBlur()\"\r\n  (focus)=\"_onFocus()\"\r\n  class=\"ngx-mat-select-search-box-input\"\r\n  type=\"text\"\r\n  #searchBox\r\n  [(ngModel)]=\"value\"\r\n  [placeholder]=\"placeholder || ''\"\r\n  (keydown)=\"handleKeydown.emit($event)\" />\r\n", styles: [".ngx-mat-select-search-box{display:flex;align-items:center;width:100%;height:56px;border:1px solid;outline:0;border-radius:4px;padding-top:16px;padding-bottom:16px;font-size:14px}.ngx-mat-select-search-box--focused{outline:1px solid}.ngx-mat-select-search-box-icon{display:flex;align-items:baseline;justify-content:center;width:36px;cursor:pointer}.ngx-mat-select-search-box-input{outline:0;border:0;width:100%;background-color:#0000;font:inherit;letter-spacing:inherit;text-decoration:inherit;text-transform:inherit}\n"], dependencies: [{ kind: "directive", type: i1$1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i2$1.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i2$1.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i2$1.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { kind: "component", type: NgxMatSelectIconComponent, selector: "ngx-mat-select-icon", inputs: ["icon", "width", "height"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.9", ngImport: i0, type: NgxMatSelectSearchBoxComponent, decorators: [{
            type: Component,
            args: [{ selector: 'ngx-mat-select-search-box', changeDetection: ChangeDetectionStrategy.OnPush, encapsulation: ViewEncapsulation.None, host: {
                        class: 'ngx-mat-select-search-box',
                        '[class.ngx-mat-select-search-box--focused]': 'focused',
                    }, template: "<div class=\"ngx-mat-select-search-box-icon\">\r\n  <div *ngIf=\"!value\">\r\n    <ngx-mat-select-icon icon=\"Search\"> </ngx-mat-select-icon>\r\n  </div>\r\n\r\n  <div (click)=\"clear()\" *ngIf=\"!!value\">\r\n    <ngx-mat-select-icon icon=\"Times\"> </ngx-mat-select-icon>\r\n  </div>\r\n</div>\r\n\r\n<input\r\n  (blur)=\"_onBlur()\"\r\n  (focus)=\"_onFocus()\"\r\n  class=\"ngx-mat-select-search-box-input\"\r\n  type=\"text\"\r\n  #searchBox\r\n  [(ngModel)]=\"value\"\r\n  [placeholder]=\"placeholder || ''\"\r\n  (keydown)=\"handleKeydown.emit($event)\" />\r\n", styles: [".ngx-mat-select-search-box{display:flex;align-items:center;width:100%;height:56px;border:1px solid;outline:0;border-radius:4px;padding-top:16px;padding-bottom:16px;font-size:14px}.ngx-mat-select-search-box--focused{outline:1px solid}.ngx-mat-select-search-box-icon{display:flex;align-items:baseline;justify-content:center;width:36px;cursor:pointer}.ngx-mat-select-search-box-input{outline:0;border:0;width:100%;background-color:#0000;font:inherit;letter-spacing:inherit;text-decoration:inherit;text-transform:inherit}\n"] }]
        }], propDecorators: { searchBox: [{
                type: ViewChild,
                args: ['searchBox']
            }], search: [{
                type: Output
            }], handleKeydown: [{
                type: Output
            }], debounceTime: [{
                type: Input
            }], placeholder: [{
                type: Input
            }] } });

/**
 * to show the custom template inside the options
 */
class NgxMatSelectOptionContentDirective {
    constructor(template) {
        this.template = template;
    }
}
NgxMatSelectOptionContentDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.9", ngImport: i0, type: NgxMatSelectOptionContentDirective, deps: [{ token: i0.TemplateRef }], target: i0.ɵɵFactoryTarget.Directive });
NgxMatSelectOptionContentDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "15.2.9", type: NgxMatSelectOptionContentDirective, selector: "[ngxMatSelectOptionContent]", ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.9", ngImport: i0, type: NgxMatSelectOptionContentDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[ngxMatSelectOptionContent]',
                }]
        }], ctorParameters: function () { return [{ type: i0.TemplateRef }]; } });

/**
 * to show a custom template for the selected options inside the form-field
 */
class NgxMatSelectTriggerDirective {
    constructor(template) {
        this.template = template;
    }
}
NgxMatSelectTriggerDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.9", ngImport: i0, type: NgxMatSelectTriggerDirective, deps: [{ token: i0.TemplateRef }], target: i0.ɵɵFactoryTarget.Directive });
NgxMatSelectTriggerDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "15.2.9", type: NgxMatSelectTriggerDirective, selector: "[ngxMatSelectTrigger]", ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.9", ngImport: i0, type: NgxMatSelectTriggerDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[ngxMatSelectTrigger]',
                }]
        }], ctorParameters: function () { return [{ type: i0.TemplateRef }]; } });

/** Injection token that can be used to provide the default options the select module. */
const NGX_MAT_SELECT_CONFIG = new InjectionToken('NGX_MAT_SELECT_CONFIG');

/**
 * Returns an exception to be thrown when attempting to change a select's `multiple` option
 * after initialization.
 * @docs-private
 */
function getSelectDynamicMultipleError() {
    return Error('Cannot change `multiple` mode of select after initialization.');
}
function getSelectOptionLabelError() {
    return Error('lib-select error: optionLabel is not defined');
}

class NgxMatSelectOptionDirective {
    constructor(option) {
        this.option = option;
    }
    /**
     * if true the option gets selected
     * @param value
     */
    set selected(value) {
        if (value) {
            this.option.select();
        }
        else {
            this.option.deselect();
        }
    }
    /**
     * if true the option gets activated
     * @param activated
     */
    set activated(activated) {
        if (activated) {
            this.option.setActiveStyles();
        }
        else {
            this.option.setInactiveStyles();
        }
    }
}
NgxMatSelectOptionDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.9", ngImport: i0, type: NgxMatSelectOptionDirective, deps: [{ token: i1$2.MatOption }], target: i0.ɵɵFactoryTarget.Directive });
NgxMatSelectOptionDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "15.2.9", type: NgxMatSelectOptionDirective, selector: "mat-option[ngxMatSelectOption]", inputs: { selected: "selected", activated: "activated" }, host: { classAttribute: "ngx-mat-select-option" }, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.9", ngImport: i0, type: NgxMatSelectOptionDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: 'mat-option[ngxMatSelectOption]',
                    host: {
                        class: 'ngx-mat-select-option',
                    },
                }]
        }], ctorParameters: function () { return [{ type: i1$2.MatOption }]; }, propDecorators: { selected: [{
                type: Input
            }], activated: [{
                type: Input
            }] } });

/**
 * a loading inside the panel when there is a delay in loading the data
 */
class NgxMatSelectLoadingComponent {
    constructor() {
        /**
         * if ture the spinner gets appeared
         */
        this.loading = false;
    }
}
NgxMatSelectLoadingComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.9", ngImport: i0, type: NgxMatSelectLoadingComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
NgxMatSelectLoadingComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.9", type: NgxMatSelectLoadingComponent, selector: "ngx-mat-select-loading", inputs: { loading: "loading" }, ngImport: i0, template: "<div *ngIf=\"loading\" class=\"lib-select-loading\">\r\n  <mat-progress-bar mode=\"indeterminate\"></mat-progress-bar>\r\n</div>\r\n", styles: [".lib-select-loading{width:100%;display:flex;align-items:center;justify-content:center;position:absolute;bottom:0;left:0;right:0;-webkit-backdrop-filter:blur(1.2px);backdrop-filter:blur(1.2px)}\n"], dependencies: [{ kind: "directive", type: i1$1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "component", type: i2$2.MatProgressBar, selector: "mat-progress-bar", inputs: ["color", "value", "bufferValue", "mode"], outputs: ["animationEnd"], exportAs: ["matProgressBar"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.9", ngImport: i0, type: NgxMatSelectLoadingComponent, decorators: [{
            type: Component,
            args: [{ selector: 'ngx-mat-select-loading', changeDetection: ChangeDetectionStrategy.OnPush, template: "<div *ngIf=\"loading\" class=\"lib-select-loading\">\r\n  <mat-progress-bar mode=\"indeterminate\"></mat-progress-bar>\r\n</div>\r\n", styles: [".lib-select-loading{width:100%;display:flex;align-items:center;justify-content:center;position:absolute;bottom:0;left:0;right:0;-webkit-backdrop-filter:blur(1.2px);backdrop-filter:blur(1.2px)}\n"] }]
        }], propDecorators: { loading: [{
                type: Input
            }] } });

/**
 * to get the value of the specific property (optionLabel) from the option
 */
class ToOptionLabelPipe {
    /**
     * to get the value of the specific property (optionLabel) from the option
     * @param option
     * @param optionLabel
     */
    transform(option, optionLabel) {
        return this.getOptionLabel(option, optionLabel);
    }
    getOptionLabel(option, optionLabel) {
        if (Array.isArray(option)) {
            return option.map(s => this.getOptionLabel(s, optionLabel)).join(', ');
        }
        else {
            return option !== null && optionLabel && typeof option === 'object' ? option[optionLabel] : option;
        }
    }
}
ToOptionLabelPipe.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.9", ngImport: i0, type: ToOptionLabelPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe });
ToOptionLabelPipe.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "15.2.9", ngImport: i0, type: ToOptionLabelPipe, name: "toOptionLabel" });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.9", ngImport: i0, type: ToOptionLabelPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'toOptionLabel',
                }]
        }] });

/**
 * a component which shows all selected options inside the form-field
 */
class NgxMatSelectTriggerComponent {
    constructor() {
        /**
         * it raises an event to remove an item from the selected options
         */
        this.deselect = new EventEmitter();
        /**
         * if the trigger is empty or not, the default value is true
         */
        this.empty = true;
        /**
         * to disable the trigger
         */
        this.disabled = false;
        /**
         * if it's true it shows the multiple text and chips
         */
        this.multiple = false;
        /**
         * how to show the selected options inside the form-field when the multiple value it's true
         */
        this.multipleDisplay = 'multipleRowChip';
    }
}
NgxMatSelectTriggerComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.9", ngImport: i0, type: NgxMatSelectTriggerComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
NgxMatSelectTriggerComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.9", type: NgxMatSelectTriggerComponent, selector: "ngx-mat-select-trigger", inputs: { customTrigger: "customTrigger", selection: "selection", empty: "empty", placeholder: "placeholder", disabled: "disabled", multiple: "multiple", optionLabel: "optionLabel", multipleDisplay: "multipleDisplay" }, outputs: { deselect: "deselect" }, host: { classAttribute: "ngx-mat-select-trigger" }, ngImport: i0, template: "<ng-template #defaultTrigger>\r\n  <ng-container *ngIf=\"multiple; else singleTemplate\">\r\n    <mat-chip-grid [disabled]=\"disabled\" *ngIf=\"multipleDisplay !== 'text'\" class=\"ngx-mat-select-chips\"\r\n                   #multipleTemplate>\r\n      <div [ngClass]=\"['ngx-mat-select-chip-grid-row', 'ngx-mat-select-chip-grid-row--' + multipleDisplay]\">\r\n        <mat-chip-row *ngFor=\"let selected of selection\" (removed)=\"deselect.emit(selected)\" [editable]=\"false\">\r\n          {{ selected | toOptionLabel: optionLabel }}\r\n          <button matChipRemove>\r\n            <ngx-mat-select-icon class=\"ngx-mat-select-chip-grid-row-icon\" [width]=\"18\" [height]=\"18\"\r\n                                 icon=\"Remove\"></ngx-mat-select-icon>\r\n          </button>\r\n        </mat-chip-row>\r\n      </div>\r\n      <input readonly type=\"text\" [matChipInputFor]=\"multipleTemplate\" class=\"ngx-mat-select-input-chips\"/>\r\n    </mat-chip-grid>\r\n\r\n    <ng-container *ngIf=\"multipleDisplay === 'text'\">\r\n      <div class=\"ngx-mat-select-value\">\r\n        {{ selection | toOptionLabel: optionLabel }}\r\n      </div>\r\n    </ng-container>\r\n  </ng-container>\r\n\r\n  <ng-template #singleTemplate>\r\n    <div class=\"ngx-mat-select-value\">{{ selection[0] | toOptionLabel: optionLabel }}</div>\r\n  </ng-template>\r\n</ng-template>\r\n\r\n<div class=\"ngx-mat-select-value ngx-mat-select-value--{{ multipleDisplay }}\" [ngSwitch]=\"empty\">\r\n  <span class=\"ngx-mat-select-placeholder ngx-mat-select-min-line\" *ngSwitchCase=\"true\">{{ placeholder }}</span>\r\n  <span class=\"ngx-mat-select-value-text\" *ngSwitchCase=\"false\" [ngSwitch]=\"!!customTrigger\">\r\n    <span class=\"ngx-mat-select-min-line\" *ngSwitchDefault>\r\n      <ng-container [ngTemplateOutlet]=\"defaultTrigger\"></ng-container>\r\n    </span>\r\n    <ng-container *ngSwitchCase=\"true\">\r\n      <ng-container *ngIf=\"customTrigger\">\r\n                              <ng-container\r\n                                *ngTemplateOutlet=\"customTrigger; context: {$implicit: multiple ? selection : selection[0]}\"></ng-container>\r\n      </ng-container>\r\n\r\n    </ng-container>\r\n  </span>\r\n</div>\r\n<div class=\"ngx-mat-select-arrow-wrapper\">\r\n  <ngx-mat-select-icon class=\"ngx-mat-select-arrow\" icon=\"ArrowDown\"></ngx-mat-select-icon>\r\n</div>\r\n", dependencies: [{ kind: "directive", type: i1$1.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i1$1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i1$1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i1$1.NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "directive", type: i1$1.NgSwitch, selector: "[ngSwitch]", inputs: ["ngSwitch"] }, { kind: "directive", type: i1$1.NgSwitchCase, selector: "[ngSwitchCase]", inputs: ["ngSwitchCase"] }, { kind: "directive", type: i1$1.NgSwitchDefault, selector: "[ngSwitchDefault]" }, { kind: "component", type: i2$3.MatChipGrid, selector: "mat-chip-grid", inputs: ["tabIndex", "disabled", "placeholder", "required", "value", "errorStateMatcher"], outputs: ["change", "valueChange"] }, { kind: "directive", type: i2$3.MatChipInput, selector: "input[matChipInputFor]", inputs: ["matChipInputFor", "matChipInputAddOnBlur", "matChipInputSeparatorKeyCodes", "placeholder", "id", "disabled"], outputs: ["matChipInputTokenEnd"], exportAs: ["matChipInput", "matChipInputFor"] }, { kind: "directive", type: i2$3.MatChipRemove, selector: "[matChipRemove]" }, { kind: "component", type: i2$3.MatChipRow, selector: "mat-chip-row, [mat-chip-row], mat-basic-chip-row, [mat-basic-chip-row]", inputs: ["color", "disabled", "disableRipple", "tabIndex", "editable"], outputs: ["edited"] }, { kind: "component", type: NgxMatSelectIconComponent, selector: "ngx-mat-select-icon", inputs: ["icon", "width", "height"] }, { kind: "pipe", type: ToOptionLabelPipe, name: "toOptionLabel" }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.9", ngImport: i0, type: NgxMatSelectTriggerComponent, decorators: [{
            type: Component,
            args: [{ selector: 'ngx-mat-select-trigger', host: {
                        class: 'ngx-mat-select-trigger',
                    }, encapsulation: ViewEncapsulation.None, changeDetection: ChangeDetectionStrategy.OnPush, template: "<ng-template #defaultTrigger>\r\n  <ng-container *ngIf=\"multiple; else singleTemplate\">\r\n    <mat-chip-grid [disabled]=\"disabled\" *ngIf=\"multipleDisplay !== 'text'\" class=\"ngx-mat-select-chips\"\r\n                   #multipleTemplate>\r\n      <div [ngClass]=\"['ngx-mat-select-chip-grid-row', 'ngx-mat-select-chip-grid-row--' + multipleDisplay]\">\r\n        <mat-chip-row *ngFor=\"let selected of selection\" (removed)=\"deselect.emit(selected)\" [editable]=\"false\">\r\n          {{ selected | toOptionLabel: optionLabel }}\r\n          <button matChipRemove>\r\n            <ngx-mat-select-icon class=\"ngx-mat-select-chip-grid-row-icon\" [width]=\"18\" [height]=\"18\"\r\n                                 icon=\"Remove\"></ngx-mat-select-icon>\r\n          </button>\r\n        </mat-chip-row>\r\n      </div>\r\n      <input readonly type=\"text\" [matChipInputFor]=\"multipleTemplate\" class=\"ngx-mat-select-input-chips\"/>\r\n    </mat-chip-grid>\r\n\r\n    <ng-container *ngIf=\"multipleDisplay === 'text'\">\r\n      <div class=\"ngx-mat-select-value\">\r\n        {{ selection | toOptionLabel: optionLabel }}\r\n      </div>\r\n    </ng-container>\r\n  </ng-container>\r\n\r\n  <ng-template #singleTemplate>\r\n    <div class=\"ngx-mat-select-value\">{{ selection[0] | toOptionLabel: optionLabel }}</div>\r\n  </ng-template>\r\n</ng-template>\r\n\r\n<div class=\"ngx-mat-select-value ngx-mat-select-value--{{ multipleDisplay }}\" [ngSwitch]=\"empty\">\r\n  <span class=\"ngx-mat-select-placeholder ngx-mat-select-min-line\" *ngSwitchCase=\"true\">{{ placeholder }}</span>\r\n  <span class=\"ngx-mat-select-value-text\" *ngSwitchCase=\"false\" [ngSwitch]=\"!!customTrigger\">\r\n    <span class=\"ngx-mat-select-min-line\" *ngSwitchDefault>\r\n      <ng-container [ngTemplateOutlet]=\"defaultTrigger\"></ng-container>\r\n    </span>\r\n    <ng-container *ngSwitchCase=\"true\">\r\n      <ng-container *ngIf=\"customTrigger\">\r\n                              <ng-container\r\n                                *ngTemplateOutlet=\"customTrigger; context: {$implicit: multiple ? selection : selection[0]}\"></ng-container>\r\n      </ng-container>\r\n\r\n    </ng-container>\r\n  </span>\r\n</div>\r\n<div class=\"ngx-mat-select-arrow-wrapper\">\r\n  <ngx-mat-select-icon class=\"ngx-mat-select-arrow\" icon=\"ArrowDown\"></ngx-mat-select-icon>\r\n</div>\r\n" }]
        }], propDecorators: { deselect: [{
                type: Output
            }], customTrigger: [{
                type: Input
            }], selection: [{
                type: Input
            }], empty: [{
                type: Input
            }], placeholder: [{
                type: Input
            }], disabled: [{
                type: Input
            }], multiple: [{
                type: Input
            }], optionLabel: [{
                type: Input
            }], multipleDisplay: [{
                type: Input
            }] } });

let nextUniqueId = 0;
// Boilerplate for applying mixins to SelectBox.
/** @docs-private */
const _MatSelectMixinBase = mixinDisableRipple(mixinTabIndex(mixinDisabled(mixinErrorState(class {
    constructor(_elementRef, _defaultErrorStateMatcher, _parentForm, _parentFormGroup, 
    /**
     * Form control bound to the component.
     * Implemented as part of `MatFormFieldControl`.
     * @docs-private
     */
    ngControl) {
        this._elementRef = _elementRef;
        this._defaultErrorStateMatcher = _defaultErrorStateMatcher;
        this._parentForm = _parentForm;
        this._parentFormGroup = _parentFormGroup;
        this.ngControl = ngControl;
        /**
         * Emits whenever the component state changes and should cause the parent
         * form-field to update. Implemented as part of `MatFormFieldControl`.
         * @docs-private
         */
        this.stateChanges = new Subject();
    }
}))));
/**
 * a select box to select multiple and single options from some provided options
 * this works with MatFormField
 */
class NgxMatSelectComponent extends _MatSelectMixinBase {
    constructor(_changeDetectorRef, renderer, _defaultErrorStateMatcher, elementRef, tabIndex, _parentForm, _parentFormGroup, _parentFormField, ngControl, defaultOptions) {
        var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l, _m, _o, _p, _q, _r, _s;
        super(elementRef, _defaultErrorStateMatcher, _parentForm, _parentFormGroup, ngControl);
        this._changeDetectorRef = _changeDetectorRef;
        this.renderer = renderer;
        this._parentFormField = _parentFormField;
        this.defaultOptions = defaultOptions;
        /** Event emitted when the select panel has been toggled. */
        this.openedChange = new EventEmitter();
        /**
         * to emits a new event, whenever the client select or deselect that item
         */
        this.selectionChange = new EventEmitter();
        /** Event emitted when the select has been opened. */
        this.opened = this.openedChange.pipe(filter(o => o), map(() => {
        }));
        /** Event emitted when the select has been closed. */
        this.closed = this.openedChange.pipe(filter(o => !o), map(() => {
        }));
        /**
         * Event that emits whenever the raw value of the select changes. This is here primarily
         * to facilitate the two-way binding for the `value` input.
         * @docs-private
         */
        this.valueChange = new EventEmitter();
        this._multiple = false;
        /** Aria label of the select. */
        this.ariaLabel = '';
        /**
         * to show a button next to the search-box to close the panel
         */
        this.hasBackButton = (_b = (_a = this.defaultOptions) === null || _a === void 0 ? void 0 : _a.hasBackButton) !== null && _b !== void 0 ? _b : false;
        /**
         * the height of an option, it's really important to handle the virtual scroll
         * the default value is 48
         */
        this.optionHeight = (_d = (_c = this.defaultOptions) === null || _c === void 0 ? void 0 : _c.optionHeight) !== null && _d !== void 0 ? _d : 48;
        /**
         * the height of the panel of the options
         * the default value is 350
         */
        this.panelHeight = (_f = (_e = this.defaultOptions) === null || _e === void 0 ? void 0 : _e.panelHeight) !== null && _f !== void 0 ? _f : 350;
        /**
         * it can be 'Default', 'FullScreen' or 'BottomSheet'
         * 'Default' means the panel will be showed connected to the form-filed
         * 'FullScreen' means the panel will be opened in full-screen mode
         * 'BottomSheet' means the panel will be opened from bottom to semi top
         */
        this.viewType = (_h = (_g = this.defaultOptions) === null || _g === void 0 ? void 0 : _g.viewType) !== null && _h !== void 0 ? _h : 'Default';
        /**
         * Width of the panel. If set to `auto`, the panel will match the trigger width.
         * If set to null or an empty string, the panel will grow to match the longest option's text.
         * the default value is 'auto'
         */
        this.panelWidth = this.defaultOptions && typeof this.defaultOptions.panelWidth !== 'undefined'
            ? this.defaultOptions.panelWidth
            : 'auto';
        /** Classes to be passed to the select panel. Supports the same syntax as `ngClass`. */
        this.panelClass = [];
        /**
         * Name of the label field of an option
         * it can be undefined, when options are simple primitive values such as a string array
         */
        this.optionLabel = (_j = this.defaultOptions) === null || _j === void 0 ? void 0 : _j.optionLabel;
        /**
         * Name of the value field of an option.
         * If optionValue is omitted and the object has no value property, the object itself becomes the value of an option. Note that,
         * when options are simple primitive values such as a string array, no optionLabel and optionValue would be necessary
         */
        this.optionValue = (_k = this.defaultOptions) === null || _k === void 0 ? void 0 : _k.optionValue;
        /**
         * how to show the selected options inside the form-field when the multiple value it's true
         * the default value is 'text'
         */
        this.multipleDisplay = (_m = (_l = this.defaultOptions) === null || _l === void 0 ? void 0 : _l.multipleDisplay) !== null && _m !== void 0 ? _m : 'text';
        /**
         * if it's true the search box will be showed, the default value is false
         */
        this.hasSearchBox = (_p = (_o = this.defaultOptions) === null || _o === void 0 ? void 0 : _o.hasSearchBox) !== null && _p !== void 0 ? _p : false;
        /**
         * a placeholder for the search-box to be shown if nothing is written in the search-box
         */
        this.searchBoxPlaceholder = (_r = (_q = this.defaultOptions) === null || _q === void 0 ? void 0 : _q.searchBoxPlaceholder) !== null && _r !== void 0 ? _r : '';
        /**
         * the options that will be appeared in the screens
         */
        this.filteredOptions$ = of([]);
        /**
         * a loading flag at button of the panel list when we are using the server-side fetching data
         */
        this.loading$ = of(false);
        /** A name for this control that can be used by `mat-form-field`. */
        this.controlType = 'ngx-mat-select';
        /** Class or list of classes to be applied to the menu's overlay panel. */
        this._overlayPanelClass = ((_s = this.defaultOptions) === null || _s === void 0 ? void 0 : _s.overlayPanelClass) || '';
        this._focused = false;
        /**
         * to store the scroll-top of the virtual scroll
         * and apply it to the virtual scroll container  whenever it gets open
         * @private
         */
        this.scrollTop = 0;
        /** Unique id for this input. */
        this._uid = `ngx-mat-select-${nextUniqueId++}`;
        /**
         * a type of subject to get the control of the value observable, storing the latest value of the form
         * @private
         */
        this.value$$ = new ReplaySubject(1);
        /** `View -> model callback called when value changes` */
        this._onChange = () => {
        };
        /** `View -> model callback called when select has been touched` */
        this._onTouched = () => {
        };
        if (this.ngControl) {
            // Note: we provide the value accessor through here, instead of
            // the `providers` to avoid running into a circular import.
            this.ngControl.valueAccessor = this;
        }
        this.value$ = this.value$$.asObservable();
        this.tabIndex = parseInt(tabIndex) || 0;
        // Force setter to be called in case id was not specified.
        // eslint-disable-next-line no-self-assign
        this.id = this.id;
    }
    /**
     * if it's false we can just select one item from the options
     */
    get multiple() {
        return this._multiple;
    }
    set multiple(value) {
        if (this.selectionModel && isDevMode()) {
            throw getSelectDynamicMultipleError();
        }
        this._multiple = coerceBooleanProperty(value);
    }
    /** Placeholder to be shown if no value has been selected. */
    get placeholder() {
        return this._placeholder;
    }
    set placeholder(value) {
        this._placeholder = isNullOrUndefined(value) ? '' : value;
        this.stateChanges.next();
    }
    /** Unique id of the element. */
    get id() {
        return this._id;
    }
    set id(value) {
        this._id = value || this._uid;
        this.stateChanges.next();
    }
    /** Whether the component is required. */
    get required() {
        var _a, _b, _c, _d;
        return (_d = (_a = this._required) !== null && _a !== void 0 ? _a : (_c = (_b = this.ngControl) === null || _b === void 0 ? void 0 : _b.control) === null || _c === void 0 ? void 0 : _c.hasValidator(Validators.required)) !== null && _d !== void 0 ? _d : false;
    }
    set required(value) {
        this._required = coerceBooleanProperty(value);
        this.stateChanges.next();
    }
    /** Value of the select control. */
    get value() {
        return this._toFlat(this.getValue());
    }
    set value(newValue) {
        this.setValue(newValue, true, false);
        this._onChange(newValue);
    }
    /** Whether the select has a value. */
    get empty() {
        return !this.selectionModel || this.selectionModel.isEmpty();
    }
    /** Whether the select is focused. */
    get focused() {
        return this._focused || this.panelOpen;
    }
    /**
     * Implemented as part of MatFormFieldControl.
     * @docs-private
     */
    get shouldLabelFloat() {
        return this.panelOpen || !this.empty || (this._focused && !!this._placeholder);
    }
    ngOnInit() {
        this.selectionModel = new SelectionModel(this.multiple, [], false, this._getCompareWithFn());
    }
    ngOnChanges(changes) {
        // Updating the disabled state is handled by `mixinDisabled`, but we need to additionally let
        // the parent form field know to run change detection when the disabled state changes.
        if (changes['disabled'] || changes['userAriaDescribedBy']) {
            this.stateChanges.next();
        }
    }
    ngDoCheck() {
        const ngControl = this.ngControl;
        if (ngControl) {
            // The disabled state might go out of sync if the form group is swapped out.
            if (this._previousControl !== ngControl.control) {
                if (this._previousControl !== undefined &&
                    ngControl.disabled !== null &&
                    ngControl.disabled !== this.disabled) {
                    this.disabled = ngControl.disabled;
                }
                this._previousControl = ngControl.control;
            }
            this.updateErrorState();
        }
    }
    /**
     * whenever the form-control gets updated from outside we can use
     * this function to write the latest value in the local state
     * @param value
     */
    writeValue(value) {
        this.setValue(value, true, false);
    }
    /**
     * to store the local onChange function
     * @param fn
     */
    registerOnChange(fn) {
        this._onChange = fn;
    }
    /**
     * to store the local onTouch function
     * @param fn
     */
    registerOnTouched(fn) {
        this._onTouched = fn;
    }
    /**
     * to manage being disabled
     * @param isDisabled
     */
    setDisabledState(isDisabled) {
        this.disabled = isDisabled;
        this._changeDetectorRef.markForCheck();
        this.stateChanges.next();
    }
    /**
     * to remove an item from the selected options
     * @param option
     */
    onDeselect(option) {
        var _a;
        (_a = this.selectionModel) === null || _a === void 0 ? void 0 : _a.deselect(option);
        const flatValue = this.getFlatValueFromSelection();
        this.setValue(flatValue, false, true);
        if (!this.panel.isOpen) {
            this.blur();
        }
        else {
            this.stateChanges.next();
        }
        this.selectionChange.emit({
            selected: false,
            value: this.getOptionValue(option),
        });
    }
    /**
     * to select or deselect an item from selected options
     * @param event
     */
    onSelectionChange(event) {
        var _a, _b;
        if (event.isUserInput) {
            const option = event.source.value;
            if (event.source.selected) {
                (_a = this.selectionModel) === null || _a === void 0 ? void 0 : _a.select(option);
            }
            else {
                (_b = this.selectionModel) === null || _b === void 0 ? void 0 : _b.deselect(option);
            }
            const flatValue = this.getFlatValueFromSelection();
            this.setValue(flatValue, false, true);
            if (!this.panel.isOpen) {
                this.blur();
            }
            else {
                this.stateChanges.next();
            }
            if (!this.multiple) {
                this.panel.close();
            }
            else {
                this._changeDetectorRef.detectChanges();
                this.panel.updatePosition();
            }
            this.selectionChange.emit({
                selected: event.source.selected,
                value: this.getOptionValue(option),
            });
        }
    }
    /**
     * Implemented as part of MatFormFieldControl.
     * @docs-private
     */
    onContainerClick(event) {
        this.panel.open();
    }
    /**
     * Implemented as part of MatFormFieldControl.
     * @docs-private
     */
    setDescribedByIds(ids) {
        if (ids.length) {
            this._elementRef.nativeElement.setAttribute('aria-describedby', ids.join(' '));
        }
        else {
            this._elementRef.nativeElement.removeAttribute('aria-describedby');
        }
    }
    /**
     * we get a hook before the panel gets open
     */
    onBeforePanelOpen() {
        this.focus();
        if (this._parentFormField) {
            this.preferredOverlayOrigin = this._parentFormField.getConnectedOverlayOrigin();
        }
    }
    /**
     * we get a hook after the panel gets open
     */
    onAfterPanelOpen() {
        this.focus();
        this.renderer.setProperty(this.virtualScroll.elementRef.nativeElement, 'scrollTop', this.scrollTop);
        setTimeout(() => {
            this.virtualScroll.checkViewportSize();
        });
        this.openedChange.emit(this.panelOpen);
    }
    /**
     * we get a hook before the panel gets close
     */
    onBeforePanelClose() {
        this.scrollTop = this.virtualScroll.elementRef.nativeElement.scrollTop || 0;
        this.blur();
    }
    /**
     * we get a hook after the panel gets close
     */
    onAfterPanelClose() {
        this.blur();
        this.openedChange.emit(this.panelOpen);
    }
    blur() {
        var _a;
        if (!this.disabled) {
            this._focused = false;
            this._onTouched();
            this._changeDetectorRef.markForCheck();
            this.stateChanges.next();
            (_a = this.searchBoxComponent) === null || _a === void 0 ? void 0 : _a.blur();
        }
    }
    focus() {
        var _a;
        if (!this.disabled) {
            this._focused = true;
            this._changeDetectorRef.markForCheck();
            this.stateChanges.next();
            (_a = this.searchBoxComponent) === null || _a === void 0 ? void 0 : _a.focus();
        }
    }
    /**
     * to get the value of the specific property (optionValue) from the option
     * @param option
     */
    getOptionValue(option) {
        return this.getObjectValue(option, this.optionValue);
    }
    /**
     * to check if an options is selected or not
     */
    isSelected(option) {
        var _a;
        return ((_a = this.selectionModel) === null || _a === void 0 ? void 0 : _a.isSelected(option)) || false;
    }
    /** The currently selected option. */
    get selected() {
        var _a, _b;
        return this.multiple ? ((_a = this.selectionModel) === null || _a === void 0 ? void 0 : _a.selected) || [] : (_b = this.selectionModel) === null || _b === void 0 ? void 0 : _b.selected[0];
    }
    /**
     * to get the latest value of the select-box
     * the value for multiple and single selection is an array,
     * but for single selection the first row is assumed as the value
     */
    getValue() {
        let value;
        this.value$$.pipe(take(1)).subscribe(selectValue => {
            value = selectValue.value;
        });
        return value || [];
    }
    /**
     * to set the value of the select-box,
     * @param value {unknown} - the value of the form-control
     * @param shouldBeSyncedWithSelection {boolean} - if it's true the selection model will be synced with the value
     * @param emitsValue - to emit and call valueChange and _onChange functions together
     */
    setValue(value, shouldBeSyncedWithSelection, emitsValue = false) {
        this.value$$.next({
            value: !isNullOrUndefined(value) ? this._toArray(value) : value,
            shouldBeSyncedWithSelection,
        });
        if (emitsValue) {
            this.valueChange.emit(value);
            this._onChange(value);
        }
    }
    /** Toggles the overlay panel open or closed. */
    toggle() {
        this.panelOpen ? this.panel.close() : this.panel.open();
    }
    get panelOpen() {
        var _a;
        return ((_a = this.panel) === null || _a === void 0 ? void 0 : _a.isOpen) || false;
    }
    /** Returns the theme to be used on the panel. */
    _getPanelTheme() {
        return this._parentFormField ? `mat-${this._parentFormField.color}` : '';
    }
    _onFocus() {
        if (!this.disabled) {
            this._focused = true;
            this.stateChanges.next();
        }
    }
    /**
     * Calls the touched callback only if the panel is closed. Otherwise, the trigger will
     * "blur" to the panel when it opens, causing a false positive.
     */
    _onBlur() {
        this._focused = false;
        if (!this.disabled && !this.panelOpen) {
            this._onTouched();
            this._changeDetectorRef.markForCheck();
            this.stateChanges.next();
        }
    }
    /**
     * to handle some keyboard event when the caret is on the input
     * @param event
     */
    _handleKeydown(event) {
        var _a;
        if (event.code === 'Enter') {
            if (this.visibleOptions && !isNullOrUndefined(this.activeItemIndex)) {
                const activatedOption = this.visibleOptions.find(o => o.active);
                if (activatedOption && !activatedOption.disabled) {
                    activatedOption === null || activatedOption === void 0 ? void 0 : activatedOption._getHostElement().click();
                }
            }
            return;
        }
        if (this.visibleOptions && (event.code === 'ArrowDown' || event.code === 'ArrowUp')) {
            event.preventDefault();
            let nextIndex = -1;
            let changeActiveOption = true;
            const optionsLength = this.visibleOptions.length;
            this.visibleOptions.find((o, index) => {
                if (o.active) {
                    nextIndex = index;
                    return true;
                }
                return false;
            });
            switch (event.code) {
                case 'ArrowDown':
                    {
                        if (nextIndex < optionsLength - 1) {
                            nextIndex++;
                        }
                        else {
                            changeActiveOption = false;
                        }
                    }
                    break;
                case 'ArrowUp':
                    {
                        if (nextIndex > 0) {
                            nextIndex--;
                        }
                        else {
                            changeActiveOption = false;
                        }
                    }
                    break;
            }
            if (changeActiveOption) {
                const nextOption = this.visibleOptions.get(nextIndex);
                nextOption === null || nextOption === void 0 ? void 0 : nextOption._getHostElement().scrollIntoView({ block: 'end' });
                this.activeItemIndex = (_a = nextOption === null || nextOption === void 0 ? void 0 : nextOption.id) === null || _a === void 0 ? void 0 : _a.toString();
            }
        }
    }
    /**
     * to get the appropriate value according to the being multiple or single selection
     * @param object
     */
    _toFlat(object) {
        if (!isNullOrUndefined(object)) {
            if (this.multiple) {
                return this._toArray(object);
            }
            else {
                return object[0];
            }
        }
        return object;
    }
    /**
     * to get an array from an object or an array
     * @param object
     */
    _toArray(object) {
        return Array.isArray(object) ? object : [object];
    }
    /**
     * to get a function which compares the options with values to detect the selected item
     */
    _getCompareWithFn() {
        return (o1, o2) => {
            if (this.compareWith && typeof this.compareWith === 'function') {
                return this.compareWith(o1, o2);
            }
            const value1 = this.getObjectValue(o1, this.dataKey || this.optionValue);
            const value2 = this.getObjectValue(o2, this.dataKey || this.optionValue);
            return value1 === value2;
        };
    }
    /**
     * according to using multiple or single selection, whenever we want to update the form-control value from here we need to get the
     * appropriate value for the form.
     * @private
     */
    getFlatValueFromSelection() {
        var _a;
        const selection = (_a = this.selectionModel) === null || _a === void 0 ? void 0 : _a.selected.map((s) => this.getOptionValue(s));
        return this._toFlat(selection);
    }
    /**
     * to get the value of the key property of an object safely
     * @param object -the object that we want to get the value of the key property
     * @param key - the one of the property of the object
     * @private
     */
    getObjectValue(object, key) {
        if (object !== null && key && typeof object === 'object') {
            return object[key];
        }
        return object;
    }
}
NgxMatSelectComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.9", ngImport: i0, type: NgxMatSelectComponent, deps: [{ token: i0.ChangeDetectorRef }, { token: i0.Renderer2 }, { token: i1$2.ErrorStateMatcher }, { token: i0.ElementRef }, { token: 'tabindex', attribute: true }, { token: i2$1.NgForm, optional: true }, { token: i2$1.FormGroupDirective, optional: true }, { token: MAT_FORM_FIELD, optional: true }, { token: i2$1.NgControl, optional: true, self: true }, { token: NGX_MAT_SELECT_CONFIG, optional: true }], target: i0.ɵɵFactoryTarget.Component });
NgxMatSelectComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.9", type: NgxMatSelectComponent, selector: "ngx-mat-select", inputs: { disabled: "disabled", disableRipple: "disableRipple", tabIndex: "tabIndex", multiple: "multiple", ariaLabel: ["aria-label", "ariaLabel"], hasBackButton: "hasBackButton", compareWith: "compareWith", optionHeight: "optionHeight", panelHeight: "panelHeight", viewType: "viewType", panelWidth: "panelWidth", panelClass: "panelClass", optionLabel: "optionLabel", optionValue: "optionValue", dataKey: "dataKey", multipleDisplay: "multipleDisplay", placeholder: "placeholder", id: "id", required: "required", userAriaDescribedBy: ["aria-describedby", "userAriaDescribedBy"], value: "value" }, outputs: { openedChange: "openedChange", selectionChange: "selectionChange", opened: "opened", closed: "closed", valueChange: "valueChange" }, host: { attributes: { "role": "combobox", "aria-autocomplete": "none", "aria-haspopup": "listbox", "ngSkipHydration": "" }, listeners: { "keydown": "_handleKeydown($event)", "focus": "_onFocus()", "blur": "_onBlur()" }, properties: { "attr.id": "id", "attr.tabindex": "tabIndex", "attr.aria-controls": "panelOpen ? id + \"-panel\" : null", "attr.aria-expanded": "panelOpen", "attr.aria-label": "ariaLabel || null", "attr.aria-required": "required.toString()", "attr.aria-disabled": "disabled.toString()", "attr.aria-invalid": "errorState", "class.ngx-mat-select-disabled": "disabled", "class.ngx-mat-select-invalid": "errorState", "class.ngx-mat-select-required": "required", "class.ngx-mat-select-empty": "empty", "class.ngx-mat-select-multiple": "multiple" }, classAttribute: "ngx-mat-select" }, providers: [
        { provide: MAT_OPTION_PARENT_COMPONENT, useExisting: NgxMatSelectComponent },
        { provide: MatFormFieldControl, useExisting: NgxMatSelectComponent },
    ], queries: [{ propertyName: "triggerContent", first: true, predicate: NgxMatSelectTriggerDirective, descendants: true }, { propertyName: "selectOptionContent", first: true, predicate: NgxMatSelectOptionContentDirective, descendants: true }], viewQueries: [{ propertyName: "searchBoxComponent", first: true, predicate: NgxMatSelectSearchBoxComponent, descendants: true }, { propertyName: "virtualScroll", first: true, predicate: CdkVirtualScrollViewport, descendants: true }, { propertyName: "panel", first: true, predicate: NgxMatSelectPanelComponent, descendants: true }, { propertyName: "visibleOptions", predicate: MatOption, descendants: true }], exportAs: ["ngxMatSelect"], usesInheritance: true, usesOnChanges: true, ngImport: i0, template: "<ngx-mat-select-trigger\r\n  cdk-overlay-origin\r\n  #fallbackOverlayOrigin=\"cdkOverlayOrigin\"\r\n  (click)=\"toggle()\"\r\n  (deselect)=\"onDeselect($event)\"\r\n  [disabled]=\"disabled\"\r\n  [multipleDisplay]=\"multipleDisplay\"\r\n  [selection]=\"selectionModel?.selected || []\"\r\n  [customTrigger]=\"triggerContent?.template || null\"\r\n  [multiple]=\"multiple\"\r\n  [optionLabel]=\"optionLabel\"\r\n  [placeholder]=\"placeholder\"\r\n  [empty]=\"empty\"\r\n>\r\n\r\n</ngx-mat-select-trigger>\r\n\r\n<ngx-mat-select-panel\r\n  [width]=\"panelWidth\"\r\n  [height]=\"panelHeight\"\r\n  [overlayClass]=\"_overlayPanelClass\"\r\n  [panelClass]=\"panelClass\"\r\n  (beforeOpen)=\"onBeforePanelOpen()\"\r\n  (afterOpen)=\"onAfterPanelOpen()\"\r\n  (beforeClose)=\"onBeforePanelClose()\"\r\n  (afterClose)=\"onAfterPanelClose()\"\r\n  [theme]=\"_getPanelTheme()\"\r\n  [disabled]=\"disabled\"\r\n  [viewType]=\"viewType\"\r\n  [connectedOverlayOrigin]=\"preferredOverlayOrigin || fallbackOverlayOrigin.elementRef\"\r\n>\r\n  <div class=\"ngx-mat-select-panel-header\" *ngIf=\"hasSearchBox || hasBackButton\">\r\n    <ngx-mat-select-search-box\r\n      *ngIf=\"hasSearchBox\"\r\n      class=\"ngx-mat-select-panel-search-box\"\r\n      (handleKeydown)=\"_handleKeydown($event)\"\r\n      [placeholder]=\"searchBoxPlaceholder\"\r\n    >\r\n    </ngx-mat-select-search-box>\r\n    <div class=\"ngx-mat-select-panel-header-filler\"></div>\r\n    <div class=\"ngx-mat-select-back-button\" *ngIf=\"hasBackButton\" (click)=\"panel.close()\">\r\n      <ngx-mat-select-icon icon=\"ArrowRight\" [width]=\"32\" [height]=\"32\">\r\n      </ngx-mat-select-icon>\r\n    </div>\r\n  </div>\r\n  <div class=\"ngx-mat-select-panel-content\">\r\n    <cdk-virtual-scroll-viewport\r\n      class=\"ngx-mat-select-virtual-scroll\"\r\n      [itemSize]=\"optionHeight\"\r\n    >\r\n      <ng-container *cdkVirtualFor=\"let option of filteredOptions$ | async;let index = index\">\r\n        <mat-option [style.height.px]=\"optionHeight\"\r\n                    ngxMatSelectOption\r\n                    #matOption\r\n                    [disabled]=\"option?.['disabled']\"\r\n                    [id]=\"index.toString()\"\r\n                    [activated]=\"activeItemIndex === matOption.id\"\r\n                    [selected]=\"isSelected(option)\"\r\n                    [value]=\"option\"\r\n                    (onSelectionChange)=\"onSelectionChange($event)\">\r\n          <ng-container *ngIf=\"selectOptionContent else defaultTemplate\">\r\n            <ng-container\r\n              *ngTemplateOutlet=\"selectOptionContent.template; context: {$implicit: option, isSelected: isSelected(option)}\"></ng-container>\r\n          </ng-container>\r\n\r\n          <ng-template #defaultTemplate>\r\n            {{option | toOptionLabel: optionLabel }}\r\n          </ng-template>\r\n\r\n        </mat-option>\r\n\r\n      </ng-container>\r\n    </cdk-virtual-scroll-viewport>\r\n\r\n  </div>\r\n  <div class=\"ngx-mat-select-panel-footer\">\r\n    <ng-content select=\"[ngxMatSelectFooter]\"></ng-content>\r\n  </div>\r\n  <ngx-mat-select-loading [loading]=\"(loading$ | async) === true\"></ngx-mat-select-loading>\r\n\r\n</ngx-mat-select-panel>\r\n\r\n", styles: [".mdc-menu-surface{display:none;position:absolute;box-sizing:border-box;max-width:calc(100vw - 32px);max-width:var(--mdc-menu-max-width, calc(100vw - 32px));max-height:calc(100vh - 32px);max-height:var(--mdc-menu-max-height, calc(100vh - 32px));margin:0;padding:0;transform:scale(1);transform-origin:top left;opacity:0;overflow:auto;will-change:transform,opacity;z-index:8;border-radius:4px;border-radius:var(--mdc-shape-medium, 4px);transform-origin-left:top left;transform-origin-right:top right}.mdc-menu-surface:focus{outline:none}.mdc-menu-surface--animating-open{display:inline-block;transform:scale(.8);opacity:0}.mdc-menu-surface--open{display:inline-block;transform:scale(1);opacity:1}.mdc-menu-surface--animating-closed{display:inline-block;opacity:0}[dir=rtl] .mdc-menu-surface,.mdc-menu-surface[dir=rtl]{transform-origin-left:top right;transform-origin-right:top left}.mdc-menu-surface--anchor{position:relative;overflow:visible}.mdc-menu-surface--fixed{position:fixed}.mdc-menu-surface--fullwidth{width:100%}.ngx-mat-select-panel *{box-sizing:border-box}.ngx-mat-select{display:inline-block;width:100%;outline:none}.ngx-mat-select-trigger{display:inline-flex;align-items:center;cursor:pointer;position:relative;box-sizing:border-box;width:100%}.ngx-mat-select-disabled .ngx-mat-select-trigger{-webkit-user-select:none;user-select:none;cursor:default}.ngx-mat-select-value{width:100%;overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.ngx-mat-select-value-text{white-space:nowrap;overflow:hidden;text-overflow:ellipsis}.ngx-mat-select-arrow-wrapper{height:24px;flex-shrink:0;display:inline-flex;align-items:center}.mat-form-field-appearance-fill .ngx-mat-select-arrow-wrapper{transform:translateY(-8px)}.mat-form-field-appearance-fill .mdc-text-field--no-label .ngx-mat-select-arrow-wrapper{transform:none}.ngx-mat-select-arrow{width:10px;height:5px;position:relative}.ngx-mat-select-arrow svg{fill:currentColor;position:absolute;top:50%;left:50%;transform:translate(-50%,-50%)}.cdk-high-contrast-active .ngx-mat-select-arrow svg{fill:CanvasText}.ngx-mat-select-disabled .cdk-high-contrast-active .ngx-mat-select-arrow svg{fill:GrayText}.mdc-menu-surface.ngx-mat-select-panel{width:100%;max-height:auto;position:static;outline:0;margin:0;padding:8px 0;list-style-type:none}.mdc-menu-surface.ngx-mat-select-panel:focus{outline:none}.cdk-high-contrast-active .mdc-menu-surface.ngx-mat-select-panel{outline:solid 1px}.cdk-overlay-pane:not(.ngx-mat-select-panel-above) .mdc-menu-surface.ngx-mat-select-panel{border-top-left-radius:0;border-top-right-radius:0;transform-origin:top center}.ngx-mat-select-panel-above .mdc-menu-surface.ngx-mat-select-panel{border-bottom-left-radius:0;border-bottom-right-radius:0;transform-origin:bottom center}.ngx-mat-select-placeholder{transition:color .4s .1333333333333s cubic-bezier(.25,.8,.25,1)}._mat-animation-noopable .ngx-mat-select-placeholder{transition:none}.mat-form-field-hide-placeholder .ngx-mat-select-placeholder{color:transparent;-webkit-text-fill-color:transparent;transition:none;display:block}.mat-mdc-form-field-type-ngx-mat-select.mat-form-field-appearance-fill .mat-mdc-floating-label{max-width:calc(100% - 18px)}.mat-mdc-form-field-type-ngx-mat-select.mat-form-field-appearance-fill .mdc-floating-label--float-above{max-width:calc(100% / .75 - 24px)}.mat-mdc-form-field-type-ngx-mat-select.mat-form-field-appearance-outline .mdc-notched-outline__notch{max-width:calc(100% - 60px)}.mat-mdc-form-field-type-ngx-mat-select.mat-form-field-appearance-outline .mdc-text-field--label-floating .mdc-notched-outline__notch{max-width:calc(100% - 24px)}.ngx-mat-select-min-line:empty:before{content:\" \";white-space:pre;width:1px;display:inline-block;visibility:hidden}ngx-mat-select-panel{width:0;height:0;position:absolute}.ngx-mat-select-panel{display:flex!important;flex-direction:column;box-sizing:border-box;padding:0!important}.ngx-mat-select-panel-header{display:flex;align-items:center;width:100%;padding:1rem}.ngx-mat-select-panel-search-box{flex:1 1 100%;margin:0 .5rem}.ngx-mat-select-panel-content{padding:0!important;height:100%;position:relative}.ngx-mat-select-virtual-scroll{height:100%}.ngx-mat-select-panel-bottom-sheet-view-type{inset:20% 0 0!important;width:100%!important}.ngx-mat-select-panel-full-screen-view-type{inset:0!important;width:100%!important;height:100%!important}.ngx-mat-select-panel-default-view-type{height:350px}.ngx-mat-select-panel-header-filler{flex:1 1 auto;min-height:56px}.ngx-mat-select-back-button{opacity:.7;flex:0 0 40px;display:flex;justify-content:center;cursor:pointer;transition:opacity .15s ease-in-out}.ngx-mat-select-chips{overflow:hidden}.ngx-mat-select-chip-grid-row{display:flex}.ngx-mat-select-chip-grid-row--oneRowChip{flex-wrap:nowrap}.ngx-mat-select-chip-grid-row--multipleRowChip{flex-wrap:wrap}.ngx-mat-select-chip-grid-row .ngx-mat-select-chip-grid-row-icon{display:flex;align-items:center}.ngx-mat-select-input-chips{height:0!important;width:0!important}.ngx-mat-select-value.ngx-mat-select-value--oneRowChip,.ngx-mat-select-value.ngx-mat-select-value--multipleRowChip{padding-right:.5rem}body[dir=rtl] .ngx-mat-select-value.ngx-mat-select-value--oneRowChip,body[dir=rtl] .ngx-mat-select-value.ngx-mat-select-value--multipleRowChip{padding-left:.5rem;padding-right:0}body[dir=rtl] .ngx-mat-select-back-button{transform:rotate(180deg)}\n"], dependencies: [{ kind: "directive", type: i1$1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i1$1.NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "directive", type: i4.CdkFixedSizeVirtualScroll, selector: "cdk-virtual-scroll-viewport[itemSize]", inputs: ["itemSize", "minBufferPx", "maxBufferPx"] }, { kind: "directive", type: i4.CdkVirtualForOf, selector: "[cdkVirtualFor][cdkVirtualForOf]", inputs: ["cdkVirtualForOf", "cdkVirtualForTrackBy", "cdkVirtualForTemplate", "cdkVirtualForTemplateCacheSize"] }, { kind: "component", type: i4.CdkVirtualScrollViewport, selector: "cdk-virtual-scroll-viewport", inputs: ["orientation", "appendOnly"], outputs: ["scrolledIndexChange"] }, { kind: "directive", type: i2.CdkOverlayOrigin, selector: "[cdk-overlay-origin], [overlay-origin], [cdkOverlayOrigin]", exportAs: ["cdkOverlayOrigin"] }, { kind: "directive", type: NgxMatSelectOptionDirective, selector: "mat-option[ngxMatSelectOption]", inputs: ["selected", "activated"] }, { kind: "component", type: NgxMatSelectLoadingComponent, selector: "ngx-mat-select-loading", inputs: ["loading"] }, { kind: "component", type: NgxMatSelectPanelComponent, selector: "ngx-mat-select-panel", inputs: ["hasBackdrop", "disabled", "theme", "overlayClass", "panelClass", "connectedOverlayOrigin", "width", "height", "viewType"], outputs: ["beforeClose", "afterClose", "afterOpen", "beforeOpen"] }, { kind: "component", type: NgxMatSelectSearchBoxComponent, selector: "ngx-mat-select-search-box", inputs: ["debounceTime", "placeholder"], outputs: ["search", "handleKeydown"] }, { kind: "component", type: NgxMatSelectIconComponent, selector: "ngx-mat-select-icon", inputs: ["icon", "width", "height"] }, { kind: "component", type: NgxMatSelectTriggerComponent, selector: "ngx-mat-select-trigger", inputs: ["customTrigger", "selection", "empty", "placeholder", "disabled", "multiple", "optionLabel", "multipleDisplay"], outputs: ["deselect"] }, { kind: "component", type: i1$2.MatOption, selector: "mat-option", exportAs: ["matOption"] }, { kind: "pipe", type: i1$1.AsyncPipe, name: "async" }, { kind: "pipe", type: ToOptionLabelPipe, name: "toOptionLabel" }], animations: [matSelectAnimations.transformPanelWrap], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.9", ngImport: i0, type: NgxMatSelectComponent, decorators: [{
            type: Component,
            args: [{ selector: 'ngx-mat-select', encapsulation: ViewEncapsulation.None, animations: [matSelectAnimations.transformPanelWrap], changeDetection: ChangeDetectionStrategy.OnPush, exportAs: 'ngxMatSelect', inputs: ['disabled', 'disableRipple', 'tabIndex'], host: {
                        role: 'combobox',
                        'aria-autocomplete': 'none',
                        'aria-haspopup': 'listbox',
                        class: 'ngx-mat-select',
                        '[attr.id]': 'id',
                        '[attr.tabindex]': 'tabIndex',
                        '[attr.aria-controls]': 'panelOpen ? id + "-panel" : null',
                        '[attr.aria-expanded]': 'panelOpen',
                        '[attr.aria-label]': 'ariaLabel || null',
                        '[attr.aria-required]': 'required.toString()',
                        '[attr.aria-disabled]': 'disabled.toString()',
                        '[attr.aria-invalid]': 'errorState',
                        ngSkipHydration: '',
                        '[class.ngx-mat-select-disabled]': 'disabled',
                        '[class.ngx-mat-select-invalid]': 'errorState',
                        '[class.ngx-mat-select-required]': 'required',
                        '[class.ngx-mat-select-empty]': 'empty',
                        '[class.ngx-mat-select-multiple]': 'multiple',
                        '(keydown)': '_handleKeydown($event)',
                        '(focus)': '_onFocus()',
                        '(blur)': '_onBlur()',
                    }, providers: [
                        { provide: MAT_OPTION_PARENT_COMPONENT, useExisting: NgxMatSelectComponent },
                        { provide: MatFormFieldControl, useExisting: NgxMatSelectComponent },
                    ], template: "<ngx-mat-select-trigger\r\n  cdk-overlay-origin\r\n  #fallbackOverlayOrigin=\"cdkOverlayOrigin\"\r\n  (click)=\"toggle()\"\r\n  (deselect)=\"onDeselect($event)\"\r\n  [disabled]=\"disabled\"\r\n  [multipleDisplay]=\"multipleDisplay\"\r\n  [selection]=\"selectionModel?.selected || []\"\r\n  [customTrigger]=\"triggerContent?.template || null\"\r\n  [multiple]=\"multiple\"\r\n  [optionLabel]=\"optionLabel\"\r\n  [placeholder]=\"placeholder\"\r\n  [empty]=\"empty\"\r\n>\r\n\r\n</ngx-mat-select-trigger>\r\n\r\n<ngx-mat-select-panel\r\n  [width]=\"panelWidth\"\r\n  [height]=\"panelHeight\"\r\n  [overlayClass]=\"_overlayPanelClass\"\r\n  [panelClass]=\"panelClass\"\r\n  (beforeOpen)=\"onBeforePanelOpen()\"\r\n  (afterOpen)=\"onAfterPanelOpen()\"\r\n  (beforeClose)=\"onBeforePanelClose()\"\r\n  (afterClose)=\"onAfterPanelClose()\"\r\n  [theme]=\"_getPanelTheme()\"\r\n  [disabled]=\"disabled\"\r\n  [viewType]=\"viewType\"\r\n  [connectedOverlayOrigin]=\"preferredOverlayOrigin || fallbackOverlayOrigin.elementRef\"\r\n>\r\n  <div class=\"ngx-mat-select-panel-header\" *ngIf=\"hasSearchBox || hasBackButton\">\r\n    <ngx-mat-select-search-box\r\n      *ngIf=\"hasSearchBox\"\r\n      class=\"ngx-mat-select-panel-search-box\"\r\n      (handleKeydown)=\"_handleKeydown($event)\"\r\n      [placeholder]=\"searchBoxPlaceholder\"\r\n    >\r\n    </ngx-mat-select-search-box>\r\n    <div class=\"ngx-mat-select-panel-header-filler\"></div>\r\n    <div class=\"ngx-mat-select-back-button\" *ngIf=\"hasBackButton\" (click)=\"panel.close()\">\r\n      <ngx-mat-select-icon icon=\"ArrowRight\" [width]=\"32\" [height]=\"32\">\r\n      </ngx-mat-select-icon>\r\n    </div>\r\n  </div>\r\n  <div class=\"ngx-mat-select-panel-content\">\r\n    <cdk-virtual-scroll-viewport\r\n      class=\"ngx-mat-select-virtual-scroll\"\r\n      [itemSize]=\"optionHeight\"\r\n    >\r\n      <ng-container *cdkVirtualFor=\"let option of filteredOptions$ | async;let index = index\">\r\n        <mat-option [style.height.px]=\"optionHeight\"\r\n                    ngxMatSelectOption\r\n                    #matOption\r\n                    [disabled]=\"option?.['disabled']\"\r\n                    [id]=\"index.toString()\"\r\n                    [activated]=\"activeItemIndex === matOption.id\"\r\n                    [selected]=\"isSelected(option)\"\r\n                    [value]=\"option\"\r\n                    (onSelectionChange)=\"onSelectionChange($event)\">\r\n          <ng-container *ngIf=\"selectOptionContent else defaultTemplate\">\r\n            <ng-container\r\n              *ngTemplateOutlet=\"selectOptionContent.template; context: {$implicit: option, isSelected: isSelected(option)}\"></ng-container>\r\n          </ng-container>\r\n\r\n          <ng-template #defaultTemplate>\r\n            {{option | toOptionLabel: optionLabel }}\r\n          </ng-template>\r\n\r\n        </mat-option>\r\n\r\n      </ng-container>\r\n    </cdk-virtual-scroll-viewport>\r\n\r\n  </div>\r\n  <div class=\"ngx-mat-select-panel-footer\">\r\n    <ng-content select=\"[ngxMatSelectFooter]\"></ng-content>\r\n  </div>\r\n  <ngx-mat-select-loading [loading]=\"(loading$ | async) === true\"></ngx-mat-select-loading>\r\n\r\n</ngx-mat-select-panel>\r\n\r\n", styles: [".mdc-menu-surface{display:none;position:absolute;box-sizing:border-box;max-width:calc(100vw - 32px);max-width:var(--mdc-menu-max-width, calc(100vw - 32px));max-height:calc(100vh - 32px);max-height:var(--mdc-menu-max-height, calc(100vh - 32px));margin:0;padding:0;transform:scale(1);transform-origin:top left;opacity:0;overflow:auto;will-change:transform,opacity;z-index:8;border-radius:4px;border-radius:var(--mdc-shape-medium, 4px);transform-origin-left:top left;transform-origin-right:top right}.mdc-menu-surface:focus{outline:none}.mdc-menu-surface--animating-open{display:inline-block;transform:scale(.8);opacity:0}.mdc-menu-surface--open{display:inline-block;transform:scale(1);opacity:1}.mdc-menu-surface--animating-closed{display:inline-block;opacity:0}[dir=rtl] .mdc-menu-surface,.mdc-menu-surface[dir=rtl]{transform-origin-left:top right;transform-origin-right:top left}.mdc-menu-surface--anchor{position:relative;overflow:visible}.mdc-menu-surface--fixed{position:fixed}.mdc-menu-surface--fullwidth{width:100%}.ngx-mat-select-panel *{box-sizing:border-box}.ngx-mat-select{display:inline-block;width:100%;outline:none}.ngx-mat-select-trigger{display:inline-flex;align-items:center;cursor:pointer;position:relative;box-sizing:border-box;width:100%}.ngx-mat-select-disabled .ngx-mat-select-trigger{-webkit-user-select:none;user-select:none;cursor:default}.ngx-mat-select-value{width:100%;overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.ngx-mat-select-value-text{white-space:nowrap;overflow:hidden;text-overflow:ellipsis}.ngx-mat-select-arrow-wrapper{height:24px;flex-shrink:0;display:inline-flex;align-items:center}.mat-form-field-appearance-fill .ngx-mat-select-arrow-wrapper{transform:translateY(-8px)}.mat-form-field-appearance-fill .mdc-text-field--no-label .ngx-mat-select-arrow-wrapper{transform:none}.ngx-mat-select-arrow{width:10px;height:5px;position:relative}.ngx-mat-select-arrow svg{fill:currentColor;position:absolute;top:50%;left:50%;transform:translate(-50%,-50%)}.cdk-high-contrast-active .ngx-mat-select-arrow svg{fill:CanvasText}.ngx-mat-select-disabled .cdk-high-contrast-active .ngx-mat-select-arrow svg{fill:GrayText}.mdc-menu-surface.ngx-mat-select-panel{width:100%;max-height:auto;position:static;outline:0;margin:0;padding:8px 0;list-style-type:none}.mdc-menu-surface.ngx-mat-select-panel:focus{outline:none}.cdk-high-contrast-active .mdc-menu-surface.ngx-mat-select-panel{outline:solid 1px}.cdk-overlay-pane:not(.ngx-mat-select-panel-above) .mdc-menu-surface.ngx-mat-select-panel{border-top-left-radius:0;border-top-right-radius:0;transform-origin:top center}.ngx-mat-select-panel-above .mdc-menu-surface.ngx-mat-select-panel{border-bottom-left-radius:0;border-bottom-right-radius:0;transform-origin:bottom center}.ngx-mat-select-placeholder{transition:color .4s .1333333333333s cubic-bezier(.25,.8,.25,1)}._mat-animation-noopable .ngx-mat-select-placeholder{transition:none}.mat-form-field-hide-placeholder .ngx-mat-select-placeholder{color:transparent;-webkit-text-fill-color:transparent;transition:none;display:block}.mat-mdc-form-field-type-ngx-mat-select.mat-form-field-appearance-fill .mat-mdc-floating-label{max-width:calc(100% - 18px)}.mat-mdc-form-field-type-ngx-mat-select.mat-form-field-appearance-fill .mdc-floating-label--float-above{max-width:calc(100% / .75 - 24px)}.mat-mdc-form-field-type-ngx-mat-select.mat-form-field-appearance-outline .mdc-notched-outline__notch{max-width:calc(100% - 60px)}.mat-mdc-form-field-type-ngx-mat-select.mat-form-field-appearance-outline .mdc-text-field--label-floating .mdc-notched-outline__notch{max-width:calc(100% - 24px)}.ngx-mat-select-min-line:empty:before{content:\" \";white-space:pre;width:1px;display:inline-block;visibility:hidden}ngx-mat-select-panel{width:0;height:0;position:absolute}.ngx-mat-select-panel{display:flex!important;flex-direction:column;box-sizing:border-box;padding:0!important}.ngx-mat-select-panel-header{display:flex;align-items:center;width:100%;padding:1rem}.ngx-mat-select-panel-search-box{flex:1 1 100%;margin:0 .5rem}.ngx-mat-select-panel-content{padding:0!important;height:100%;position:relative}.ngx-mat-select-virtual-scroll{height:100%}.ngx-mat-select-panel-bottom-sheet-view-type{inset:20% 0 0!important;width:100%!important}.ngx-mat-select-panel-full-screen-view-type{inset:0!important;width:100%!important;height:100%!important}.ngx-mat-select-panel-default-view-type{height:350px}.ngx-mat-select-panel-header-filler{flex:1 1 auto;min-height:56px}.ngx-mat-select-back-button{opacity:.7;flex:0 0 40px;display:flex;justify-content:center;cursor:pointer;transition:opacity .15s ease-in-out}.ngx-mat-select-chips{overflow:hidden}.ngx-mat-select-chip-grid-row{display:flex}.ngx-mat-select-chip-grid-row--oneRowChip{flex-wrap:nowrap}.ngx-mat-select-chip-grid-row--multipleRowChip{flex-wrap:wrap}.ngx-mat-select-chip-grid-row .ngx-mat-select-chip-grid-row-icon{display:flex;align-items:center}.ngx-mat-select-input-chips{height:0!important;width:0!important}.ngx-mat-select-value.ngx-mat-select-value--oneRowChip,.ngx-mat-select-value.ngx-mat-select-value--multipleRowChip{padding-right:.5rem}body[dir=rtl] .ngx-mat-select-value.ngx-mat-select-value--oneRowChip,body[dir=rtl] .ngx-mat-select-value.ngx-mat-select-value--multipleRowChip{padding-left:.5rem;padding-right:0}body[dir=rtl] .ngx-mat-select-back-button{transform:rotate(180deg)}\n"] }]
        }], ctorParameters: function () {
        return [{ type: i0.ChangeDetectorRef }, { type: i0.Renderer2 }, { type: i1$2.ErrorStateMatcher }, { type: i0.ElementRef }, { type: undefined, decorators: [{
                        type: Attribute,
                        args: ['tabindex']
                    }] }, { type: i2$1.NgForm, decorators: [{
                        type: Optional
                    }] }, { type: i2$1.FormGroupDirective, decorators: [{
                        type: Optional
                    }] }, { type: i13.MatFormField, decorators: [{
                        type: Optional
                    }, {
                        type: Inject,
                        args: [MAT_FORM_FIELD]
                    }] }, { type: i2$1.NgControl, decorators: [{
                        type: Self
                    }, {
                        type: Optional
                    }] }, { type: undefined, decorators: [{
                        type: Optional
                    }, {
                        type: Inject,
                        args: [NGX_MAT_SELECT_CONFIG]
                    }] }];
    }, propDecorators: { visibleOptions: [{
                type: ViewChildren,
                args: [MatOption]
            }], triggerContent: [{
                type: ContentChild,
                args: [NgxMatSelectTriggerDirective]
            }], selectOptionContent: [{
                type: ContentChild,
                args: [NgxMatSelectOptionContentDirective]
            }], searchBoxComponent: [{
                type: ViewChild,
                args: [NgxMatSelectSearchBoxComponent]
            }], virtualScroll: [{
                type: ViewChild,
                args: [CdkVirtualScrollViewport]
            }], panel: [{
                type: ViewChild,
                args: [NgxMatSelectPanelComponent]
            }], openedChange: [{
                type: Output
            }], selectionChange: [{
                type: Output
            }], opened: [{
                type: Output
            }], closed: [{
                type: Output
            }], valueChange: [{
                type: Output
            }], multiple: [{
                type: Input
            }], ariaLabel: [{
                type: Input,
                args: ['aria-label']
            }], hasBackButton: [{
                type: Input
            }], compareWith: [{
                type: Input
            }], optionHeight: [{
                type: Input
            }], panelHeight: [{
                type: Input
            }], viewType: [{
                type: Input
            }], panelWidth: [{
                type: Input
            }], panelClass: [{
                type: Input
            }], optionLabel: [{
                type: Input
            }], optionValue: [{
                type: Input
            }], dataKey: [{
                type: Input
            }], multipleDisplay: [{
                type: Input
            }], placeholder: [{
                type: Input
            }], id: [{
                type: Input
            }], required: [{
                type: Input
            }], userAriaDescribedBy: [{
                type: Input,
                args: ['aria-describedby']
            }], value: [{
                type: Input
            }] } });

class SharedModule {
}
SharedModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.9", ngImport: i0, type: SharedModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
SharedModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "15.2.9", ngImport: i0, type: SharedModule, declarations: [NgxMatSelectOptionDirective, ToOptionLabelPipe], imports: [CommonModule], exports: [NgxMatSelectOptionDirective, ToOptionLabelPipe] });
SharedModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "15.2.9", ngImport: i0, type: SharedModule, providers: [ToOptionLabelPipe], imports: [CommonModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.9", ngImport: i0, type: SharedModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [NgxMatSelectOptionDirective, ToOptionLabelPipe],
                    imports: [CommonModule],
                    exports: [NgxMatSelectOptionDirective, ToOptionLabelPipe],
                    providers: [ToOptionLabelPipe],
                }]
        }] });

class NgxMatSelectFetchOptionsDirective {
    constructor(host, _changeDetectorRef) {
        this.host = host;
        this._changeDetectorRef = _changeDetectorRef;
        this._hasSearchBox = false;
        /**
         * an observable to manage the filtered options state
         */
        this.filteredOptions$ = new BehaviorSubject([]);
        /**
         * when the main stream is busy with fetching data from the server, the loading is true
         */
        this.loading$ = new BehaviorSubject(false);
        /**
         * an observable to manage destroying the other observables
         * @protected
         */
        this.destroy$ = new Subject();
        /**
         * the type of received options
         * @protected
         */
        this.optionType = 'unknown';
        /**
         * if every input initialized or not
         * @private
         */
        this.initialized = false;
        /**
         * to recognize the first empty search
         * @private
         */
        this.isFirstEmptySearch = true;
        this.host.filteredOptions$ = this.filteredOptions$.asObservable();
        this.host.loading$ = this.loading$.asObservable().pipe(distinctUntilChanged());
    }
    /**
     * if it's true the search-box will appear inside the panel
     */
    get hasSearchBox() {
        return this._hasSearchBox;
    }
    set hasSearchBox(value) {
        this._hasSearchBox = coerceBooleanProperty(value);
        if (this.host.hasSearchBox !== this._hasSearchBox) {
            this.host.hasSearchBox = this._hasSearchBox;
            this._changeDetectorRef.detectChanges();
        }
        this.checkOptionLabel();
        this.initializeSearch();
    }
    /**
     * a placeholder for the search-box to be shown if nothing is written in the search-box
     */
    set searchBoxPlaceholder(value) {
        if (this.host.searchBoxComponent && !isNullOrUndefined(value)) {
            this.host.searchBoxPlaceholder = value;
        }
    }
    ngOnInit() {
        this.initialized = true;
        if (!this.searchSubscription) {
            this.hasSearchBox = this.host.hasSearchBox;
        }
        /**
         * order of initializing matters
         */
        this.checkOptionLabel();
        this.listenToValueChanges();
        this.initSortValues();
    }
    ngAfterViewInit() {
        this.initScrollIntoSelectedOption();
    }
    ngOnDestroy() {
        this.destroy$.next(void 0);
        this.destroy$.complete();
        this.filteredOptions$.complete();
        this.loading$.complete();
    }
    /**
     * to check the type of the options to realize there are primitive or an object
     * @protected
     */
    checkOptionsType() {
        const options = this.options;
        if (!isNullOrUndefined(options) && options.length > 0) {
            if (options[0] && typeof options[0] === 'object') {
                this.optionType = 'object';
            }
            else {
                this.optionType = 'primitive';
            }
        }
        this.checkOptionLabel();
    }
    /**
     * to listen to the search-box input changes, and filter the options through the searchTerm
     * @private
     */
    initializeSearch() {
        var _a, _b;
        (_a = this.searchSubscription) === null || _a === void 0 ? void 0 : _a.unsubscribe();
        if (this.hasSearchBox) {
            this.searchSubscription = (_b = this.host.searchBoxComponent) === null || _b === void 0 ? void 0 : _b.search.pipe(startWith(''), tap(() => {
                if (!this.isFirstEmptySearch) {
                    this.host.virtualScroll.scrollToIndex(0);
                    this.host.activeItemIndex = '0';
                    this._changeDetectorRef.markForCheck();
                }
                this.isFirstEmptySearch = false;
            }), tap(searchTerm => this.search(searchTerm)), takeUntil(this.destroy$)).subscribe();
        }
        else {
            this.search('');
        }
    }
    /**
     * to check value member and display-member are required if they are required, checking they are provided or not
     * @private
     */
    checkOptionLabel() {
        if (isDevMode() && this.optionType === 'object' && this.initialized) {
            const optionLabel = this.host.optionLabel;
            if (!optionLabel) {
                throw getSelectOptionLabelError();
            }
        }
    }
    /**
     * to sync the selected items with the value of the select-box
     * @private
     */
    listenToValueChanges() {
        this.host.value$
            .pipe(filter(({ shouldBeSyncedWithSelection }) => shouldBeSyncedWithSelection), tap(() => {
            this.syncValueAndOptions();
        }), takeUntil(this.destroy$))
            .subscribe();
    }
    /**
     * to scroll to the selected option when the select has a value.
     * it works just in client side because we have whole the options and the selection mode has to be single selection,
     * @private
     */
    initScrollIntoSelectedOption() {
        var _a, _b;
        const selectionModelChanged = (_a = this.host.selectionModel) === null || _a === void 0 ? void 0 : _a.changed;
        if (selectionModelChanged) {
            this.host.panel.afterOpen
                .pipe(combineLatestWith(this.filteredOptions$.pipe(take(1)), selectionModelChanged.pipe(startWith((_b = this.host.selectionModel) === null || _b === void 0 ? void 0 : _b.selected))), withLatestFrom(this.filteredOptions$), map(([[_], filteredOptions]) => {
                var _a;
                let firstSelectedOption = undefined;
                let firstSelectedOptionIndex = -1;
                const selection = (_a = this.host.selectionModel) === null || _a === void 0 ? void 0 : _a.selected;
                if (selection) {
                    const compareWithFn = this.host._getCompareWithFn();
                    filteredOptions.some((option, index) => {
                        const firstIndex = selection.findIndex(selectedOption => compareWithFn(selectedOption, option));
                        if (firstIndex !== -1) {
                            firstSelectedOptionIndex = index;
                            firstSelectedOption = option;
                            return true;
                        }
                        return false;
                    });
                }
                return { selectedIndex: firstSelectedOptionIndex, selected: firstSelectedOption };
            }), filter(({ selectedIndex }) => selectedIndex !== -1), tap(({ selectedIndex }) => {
                this.host.virtualScroll.scrollToIndex(selectedIndex);
            }), filter(({ selected }) => !this.scrollIntoVisibleOptionView(selected)), switchMap(({ selected }) => this.host.visibleOptions.changes.pipe(tap(() => this.scrollIntoVisibleOptionView(selected)), take(1))), takeUntil(this.destroy$))
                .subscribe();
        }
    }
    /**
     * @returns - a boolean to find out whether we are successful in scroll to the selected option or not
     * it depends on whether the corresponding option is present in the options.
     * @param selected - the selected item
     * @private
     */
    scrollIntoVisibleOptionView(selected) {
        var _a;
        const compareWithFn = this.host._getCompareWithFn();
        const selectedVisibleOption = this.host.visibleOptions.find(o => compareWithFn(o.value, selected));
        if (selectedVisibleOption) {
            this.host.activeItemIndex = (_a = selectedVisibleOption.id) === null || _a === void 0 ? void 0 : _a.toString();
            selectedVisibleOption._getHostElement().scrollIntoView({ block: 'end' });
            this._changeDetectorRef.detectChanges();
        }
        return !!selectedVisibleOption;
    }
    /**
     * to sort the selected option and values with order of received options, whenever the selection or value changes
     * @private
     */
    initSortValues() {
        merge(this.host.selectionChange, this.host.value$)
            .pipe(tap(() => {
            this.sortValues();
        }), takeUntil(this.destroy$))
            .subscribe();
    }
}
NgxMatSelectFetchOptionsDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.9", ngImport: i0, type: NgxMatSelectFetchOptionsDirective, deps: [{ token: NgxMatSelectComponent }, { token: i0.ChangeDetectorRef }], target: i0.ɵɵFactoryTarget.Directive });
NgxMatSelectFetchOptionsDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "15.2.9", type: NgxMatSelectFetchOptionsDirective, inputs: { sortComparator: "sortComparator", hasSearchBox: "hasSearchBox", searchBoxPlaceholder: "searchBoxPlaceholder" }, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.9", ngImport: i0, type: NgxMatSelectFetchOptionsDirective, decorators: [{
            type: Directive
        }], ctorParameters: function () { return [{ type: NgxMatSelectComponent }, { type: i0.ChangeDetectorRef }]; }, propDecorators: { sortComparator: [{
                type: Input
            }], hasSearchBox: [{
                type: Input
            }], searchBoxPlaceholder: [{
                type: Input
            }] } });

/**
 * to fetch the whole options at once, and use a search-box if needed
 */
class NgxMatSelectFetchOptionsClientSideDirective extends NgxMatSelectFetchOptionsDirective {
    constructor(host, changeDetectorRef) {
        super(host, changeDetectorRef);
        /**
         * to search the options through the searchTerm
         * @param searchTerm
         */
        this.search = (searchTerm) => {
            const comparisonFn = (option) => {
                var _a;
                if (!isNullOrUndefined(searchTerm) && searchTerm !== '') {
                    if (this.searchComparison) {
                        return this.searchComparison(searchTerm, option);
                    }
                    else {
                        if (this.host.optionLabel && this.optionType === 'object') {
                            return (_a = option[this.host.optionLabel]) === null || _a === void 0 ? void 0 : _a.toString().includes(searchTerm);
                        }
                        else {
                            return option === null || option === void 0 ? void 0 : option.toString().includes(searchTerm);
                        }
                    }
                }
                return true;
            };
            if (!isNullOrUndefined(this.options)) {
                this.filteredOptions$.next(this.options.filter(comparisonFn).slice());
            }
        };
        /**
         * to sort the selected items according to the received options,
         * or the provided sortComparator function
         */
        this.sortValues = () => {
            var _a;
            if (this.host.multiple) {
                const options = this.options || [];
                (_a = this.host.selectionModel) === null || _a === void 0 ? void 0 : _a.sort((a, b) => {
                    return this.sortComparator ? this.sortComparator(a, b, options) : options.indexOf(a) - options.indexOf(b);
                });
                this.host.stateChanges.next();
            }
        };
        /**
         * if a value is not present in the received options, it would be omitted from the value and the selection
         */
        this.syncValueAndOptions = () => {
            if (this.host.selectionModel) {
                const value = this.host.getValue();
                const compareWithFn = this.host._getCompareWithFn();
                const options = this.options || [];
                if (!isNullOrUndefined(value)) {
                    if (options.length > 0 && value.length > 0) {
                        const selected = [];
                        value.forEach((value) => {
                            options.some((option) => {
                                if (compareWithFn(option, value)) {
                                    selected.push({ option, value });
                                    return true;
                                }
                                return false;
                            });
                        });
                        this.host.selectionModel.setSelection(...selected.map(s => s.option));
                        const selectedValue = selected.map(s => s.value);
                        this.host.setValue(this.host._toFlat(selectedValue), false, true);
                    }
                    else if (!this.loading$.getValue()) {
                        this.host.selectionModel.clear();
                        this.host.setValue(null, false, true);
                    }
                }
                else {
                    const isThereAnyNullOrUndefinedInOptions = options.filter(o => compareWithFn(o, undefined) || compareWithFn(o, null)).length > 0;
                    if (options.length > 0 && isThereAnyNullOrUndefinedInOptions) {
                        this.host.selectionModel.setSelection(value);
                    }
                    else {
                        this.host.selectionModel.clear();
                    }
                }
                this._changeDetectorRef.markForCheck();
                this.host.stateChanges.next();
            }
        };
    }
    /**
     * if true the loading indicator appears in the panel,
     * you can use this, when the options are loading for the very first time
     * @param value
     */
    set loading(value) {
        this.loading$.next(value || false);
    }
    ngOnChanges(changes) {
        var _a;
        const optionsChange = changes['options'];
        if (optionsChange && optionsChange.previousValue !== optionsChange.currentValue) {
            (_a = this.host.searchBoxComponent) === null || _a === void 0 ? void 0 : _a.clear();
            this.search('');
            this.checkOptionsType();
            this.syncValueAndOptions();
        }
    }
}
NgxMatSelectFetchOptionsClientSideDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.9", ngImport: i0, type: NgxMatSelectFetchOptionsClientSideDirective, deps: [{ token: NgxMatSelectComponent }, { token: i0.ChangeDetectorRef }], target: i0.ɵɵFactoryTarget.Directive });
NgxMatSelectFetchOptionsClientSideDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "15.2.9", type: NgxMatSelectFetchOptionsClientSideDirective, selector: "ngx-mat-select[clientSide]:not(ngx-mat-select[serverSide])", inputs: { options: "options", loading: "loading", searchComparison: "searchComparison" }, exportAs: ["ngxMatSelectClientSide"], usesInheritance: true, usesOnChanges: true, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.9", ngImport: i0, type: NgxMatSelectFetchOptionsClientSideDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: 'ngx-mat-select[clientSide]:not(ngx-mat-select[serverSide])',
                    exportAs: 'ngxMatSelectClientSide',
                }]
        }], ctorParameters: function () { return [{ type: NgxMatSelectComponent }, { type: i0.ChangeDetectorRef }]; }, propDecorators: { options: [{
                type: Input
            }], loading: [{
                type: Input
            }], searchComparison: [{
                type: Input
            }] } });

/**
 * a directive to handle server-side mode, which can get the lazy-data page per page  with the provided pageSize
 */
class NgxMatSelectFetchOptionsServerSideDirective extends NgxMatSelectFetchOptionsDirective {
    constructor(changeDetectorRef, host, scrollDispatcher) {
        super(host, changeDetectorRef);
        this.scrollDispatcher = scrollDispatcher;
        /**
         * the page size, every calculation for figuring out whether there is a next page or not based on this property
         */
        this.pageSize = 10;
        /**
         * to store the previous options to use them after coming back to the old pages
         * @private
         */
        this.options = [];
        /**
         *This would store the current page number that we are in it,
         * it stats from one
         * @private
         */
        this.pageNumber = 1;
        /**
         * an observable to force the main stream to get the new data filtered through searchTerm
         * @private
         */
        this.search$ = new ReplaySubject(1);
        /**
         * an observable to force the main stream to get next page data according to the pageNumber
         * @private
         */
        this.fetchNext$ = new BehaviorSubject(void 0);
        /**
         * if it's false when getting the next page request comes the request will be blocked
         * before sending to the server
         * @private
         */
        this.hasMore = true;
        /**
         * to search the options with the searchTerm
         * @param searchTerm
         */
        this.search = (searchTerm) => {
            this.search$.next(searchTerm);
        };
        /**
         * to sort the selected items according to the provided sortComparator function
         */
        this.sortValues = () => {
            var _a;
            if (this.host.multiple && this.options.length > 0) {
                if (!isNullOrUndefined(this.sortComparator) && typeof this.sortComparator === 'function') {
                    const sortComparator = this.sortComparator;
                    (_a = this.host.selectionModel) === null || _a === void 0 ? void 0 : _a.sort((a, b) => {
                        return sortComparator(a, b, this.options);
                    });
                    this.host.stateChanges.next();
                }
            }
        };
        /**
         * Actually in the server-side mode we would not be able to sync options with values
         * in order to omit non-exist values through the received options,
         * because we don't have all options available at once, so we don't have
         * any indicator to distinguish between them, so whatever value is provided would be set as the selected option
         */
        this.syncValueAndOptions = () => {
            var _a, _b;
            const value = this.host.getValue();
            if (isNullOrUndefined(value)) {
                (_a = this.host.selectionModel) === null || _a === void 0 ? void 0 : _a.clear();
            }
            else {
                (_b = this.host.selectionModel) === null || _b === void 0 ? void 0 : _b.setSelection(...value);
                this.sortValues();
            }
            this._changeDetectorRef.markForCheck();
            this.host.stateChanges.next();
        };
    }
    /**
     * to fetch the options from the server through searchParams
     */
    set fetchOptions(fetchFunction) {
        this.destroy$.next(void 0);
        combineLatest([this.search$, this.fetchNext$])
            .pipe(startWith(['', '']), pairwise(), map(([[prevSearchTerm], [nextSearchTerm]]) => {
            if (prevSearchTerm !== nextSearchTerm) {
                this.pageNumber = 1;
                this.hasMore = true;
                this.options = [];
            }
            return nextSearchTerm;
        }), tap(() => {
            this.loading$.next(true);
            this._changeDetectorRef.detectChanges();
        }), switchMap(searchTerm => fetchFunction({ searchTerm, pageNumber: this.pageNumber, pageSize: this.pageSize }).pipe(tap(nextOptions => {
            if (nextOptions.length > 0) {
                this.pageNumber++;
            }
            this.hasMore = (nextOptions === null || nextOptions === void 0 ? void 0 : nextOptions.length) === this.pageSize;
        }), map(nextOptions => {
            this.options = this.options.concat(...nextOptions);
            return [...this.options];
        }), tap(options => {
            this.filteredOptions$.next(options);
            this.loading$.next(false);
        }), tap(() => {
            this.checkOptionsType();
            this.sortValues();
        }), tap(() => {
            this._changeDetectorRef.detectChanges();
        }))), takeUntil(this.destroy$))
            .subscribe();
    }
    /**
     * to fetch the next page if any
     */
    fetchNext() {
        if (this.hasMore) {
            this.fetchNext$.next(void 0);
        }
    }
    ngAfterViewInit() {
        super.ngAfterViewInit();
        this.initializeInfiniteScroll();
    }
    ngOnDestroy() {
        super.ngOnDestroy();
        this.search$.complete();
        this.fetchNext$.complete();
    }
    /**
     * to listen to the virtual scroll events, and get the next page at the appropriate time.
     * @private
     */
    initializeInfiniteScroll() {
        this.scrollDispatcher
            .scrolled()
            .pipe(filter(() => this.host.virtualScroll.getRenderedRange().end === this.host.virtualScroll.getDataLength()), filter(() => !this.loading$.getValue()), tap(() => {
            this.fetchNext();
        }), takeUntil(this.destroy$))
            .subscribe();
    }
}
NgxMatSelectFetchOptionsServerSideDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.9", ngImport: i0, type: NgxMatSelectFetchOptionsServerSideDirective, deps: [{ token: i0.ChangeDetectorRef }, { token: NgxMatSelectComponent }, { token: i4.ScrollDispatcher }], target: i0.ɵɵFactoryTarget.Directive });
NgxMatSelectFetchOptionsServerSideDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "15.2.9", type: NgxMatSelectFetchOptionsServerSideDirective, selector: "ngx-mat-select[serverSide]:not(ngx-mat-select[clientSide])", inputs: { pageSize: "pageSize", fetchOptions: "fetchOptions" }, exportAs: ["ngxMatSelectServerSide"], usesInheritance: true, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.9", ngImport: i0, type: NgxMatSelectFetchOptionsServerSideDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: 'ngx-mat-select[serverSide]:not(ngx-mat-select[clientSide])',
                    exportAs: 'ngxMatSelectServerSide',
                }]
        }], ctorParameters: function () { return [{ type: i0.ChangeDetectorRef }, { type: NgxMatSelectComponent }, { type: i4.ScrollDispatcher }]; }, propDecorators: { pageSize: [{
                type: Input
            }], fetchOptions: [{
                type: Input
            }] } });

class NgxMatSelectLoadingModule {
}
NgxMatSelectLoadingModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.9", ngImport: i0, type: NgxMatSelectLoadingModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
NgxMatSelectLoadingModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "15.2.9", ngImport: i0, type: NgxMatSelectLoadingModule, declarations: [NgxMatSelectLoadingComponent], imports: [CommonModule, MatProgressBarModule], exports: [NgxMatSelectLoadingComponent] });
NgxMatSelectLoadingModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "15.2.9", ngImport: i0, type: NgxMatSelectLoadingModule, imports: [CommonModule, MatProgressBarModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.9", ngImport: i0, type: NgxMatSelectLoadingModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [NgxMatSelectLoadingComponent],
                    imports: [CommonModule, MatProgressBarModule],
                    exports: [NgxMatSelectLoadingComponent],
                }]
        }] });

class NgxMatSelectPanelModule {
}
NgxMatSelectPanelModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.9", ngImport: i0, type: NgxMatSelectPanelModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
NgxMatSelectPanelModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "15.2.9", ngImport: i0, type: NgxMatSelectPanelModule, declarations: [NgxMatSelectPanelComponent], imports: [CommonModule, CdkConnectedOverlay], exports: [NgxMatSelectPanelComponent] });
NgxMatSelectPanelModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "15.2.9", ngImport: i0, type: NgxMatSelectPanelModule, imports: [CommonModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.9", ngImport: i0, type: NgxMatSelectPanelModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [NgxMatSelectPanelComponent],
                    imports: [CommonModule, CdkConnectedOverlay],
                    exports: [NgxMatSelectPanelComponent],
                }]
        }] });

class NgxMatSelectIconModule {
}
NgxMatSelectIconModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.9", ngImport: i0, type: NgxMatSelectIconModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
NgxMatSelectIconModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "15.2.9", ngImport: i0, type: NgxMatSelectIconModule, declarations: [NgxMatSelectIconComponent], imports: [CommonModule], exports: [NgxMatSelectIconComponent] });
NgxMatSelectIconModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "15.2.9", ngImport: i0, type: NgxMatSelectIconModule, imports: [CommonModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.9", ngImport: i0, type: NgxMatSelectIconModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [NgxMatSelectIconComponent],
                    imports: [CommonModule],
                    exports: [NgxMatSelectIconComponent],
                }]
        }] });

class NgxMatSelectSearchBoxModule {
}
NgxMatSelectSearchBoxModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.9", ngImport: i0, type: NgxMatSelectSearchBoxModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
NgxMatSelectSearchBoxModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "15.2.9", ngImport: i0, type: NgxMatSelectSearchBoxModule, declarations: [NgxMatSelectSearchBoxComponent], imports: [CommonModule, FormsModule, NgxMatSelectIconModule], exports: [NgxMatSelectSearchBoxComponent] });
NgxMatSelectSearchBoxModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "15.2.9", ngImport: i0, type: NgxMatSelectSearchBoxModule, imports: [CommonModule, FormsModule, NgxMatSelectIconModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.9", ngImport: i0, type: NgxMatSelectSearchBoxModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [NgxMatSelectSearchBoxComponent],
                    imports: [CommonModule, FormsModule, NgxMatSelectIconModule],
                    exports: [NgxMatSelectSearchBoxComponent],
                }]
        }] });

class NgxMatSelectTriggerModule {
}
NgxMatSelectTriggerModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.9", ngImport: i0, type: NgxMatSelectTriggerModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
NgxMatSelectTriggerModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "15.2.9", ngImport: i0, type: NgxMatSelectTriggerModule, declarations: [NgxMatSelectTriggerComponent], imports: [CommonModule, MatChipsModule, NgxMatSelectIconModule, SharedModule], exports: [NgxMatSelectTriggerComponent] });
NgxMatSelectTriggerModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "15.2.9", ngImport: i0, type: NgxMatSelectTriggerModule, imports: [CommonModule, MatChipsModule, NgxMatSelectIconModule, SharedModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.9", ngImport: i0, type: NgxMatSelectTriggerModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [NgxMatSelectTriggerComponent],
                    imports: [CommonModule, MatChipsModule, NgxMatSelectIconModule, SharedModule],
                    exports: [NgxMatSelectTriggerComponent],
                }]
        }] });

class NgxMatSelectModule {
}
NgxMatSelectModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.9", ngImport: i0, type: NgxMatSelectModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
NgxMatSelectModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "15.2.9", ngImport: i0, type: NgxMatSelectModule, declarations: [NgxMatSelectComponent,
        NgxMatSelectFetchOptionsClientSideDirective,
        NgxMatSelectFetchOptionsServerSideDirective,
        NgxMatSelectOptionContentDirective,
        NgxMatSelectTriggerDirective], imports: [CommonModule,
        ScrollingModule,
        CdkOverlayOrigin,
        SharedModule,
        NgxMatSelectLoadingModule,
        NgxMatSelectPanelModule,
        NgxMatSelectSearchBoxModule,
        NgxMatSelectIconModule,
        NgxMatSelectTriggerModule,
        MatOptionModule], exports: [NgxMatSelectComponent,
        NgxMatSelectFetchOptionsClientSideDirective,
        NgxMatSelectFetchOptionsServerSideDirective,
        NgxMatSelectOptionContentDirective,
        NgxMatSelectTriggerDirective] });
NgxMatSelectModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "15.2.9", ngImport: i0, type: NgxMatSelectModule, imports: [CommonModule,
        ScrollingModule,
        SharedModule,
        NgxMatSelectLoadingModule,
        NgxMatSelectPanelModule,
        NgxMatSelectSearchBoxModule,
        NgxMatSelectIconModule,
        NgxMatSelectTriggerModule,
        MatOptionModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.9", ngImport: i0, type: NgxMatSelectModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        NgxMatSelectComponent,
                        NgxMatSelectFetchOptionsClientSideDirective,
                        NgxMatSelectFetchOptionsServerSideDirective,
                        NgxMatSelectOptionContentDirective,
                        NgxMatSelectTriggerDirective,
                    ],
                    imports: [
                        CommonModule,
                        ScrollingModule,
                        CdkOverlayOrigin,
                        SharedModule,
                        NgxMatSelectLoadingModule,
                        NgxMatSelectPanelModule,
                        NgxMatSelectSearchBoxModule,
                        NgxMatSelectIconModule,
                        NgxMatSelectTriggerModule,
                        MatOptionModule,
                    ],
                    exports: [
                        NgxMatSelectComponent,
                        NgxMatSelectFetchOptionsClientSideDirective,
                        NgxMatSelectFetchOptionsServerSideDirective,
                        NgxMatSelectOptionContentDirective,
                        NgxMatSelectTriggerDirective,
                    ],
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { NGX_MAT_SELECT_CONFIG, NgxMatSelectComponent, NgxMatSelectFetchOptionsClientSideDirective, NgxMatSelectFetchOptionsServerSideDirective, NgxMatSelectModule, NgxMatSelectOptionContentDirective, NgxMatSelectTriggerDirective };
//# sourceMappingURL=ngx-mat-select.mjs.map
